@@ -98,6 +98,9 @@ class DataTableGenericFilter
                   array(
                       'filter_sort_column' => array('string'),
                       'filter_sort_order'  => array('string', 'desc'),
+                      $naturalSort = true,
+                      $recursiveSort = true,
+                      $doSortBySecondaryColumn = true
                   )),
             array('Truncate',
                   array(
@@ -159,22 +162,27 @@ class DataTableGenericFilter
             }
 
             foreach ($filterParams as $name => $info) {
-                // parameter type to cast to
-                $type = $info[0];
+                if (!is_array($info)) {
+                    // hard coded value that cannot be changed via API, see eg $naturalSort = true in 'Sort'
+                    $filterParameters[] = $info;
+                } else {
+                    // parameter type to cast to
+                    $type = $info[0];
 
-                // default value if specified, when the parameter doesn't have a value
-                $defaultValue = null;
-                if (isset($info[1])) {
-                    $defaultValue = $info[1];
-                }
+                    // default value if specified, when the parameter doesn't have a value
+                    $defaultValue = null;
+                    if (isset($info[1])) {
+                        $defaultValue = $info[1];
+                    }
 
-                try {
-                    $value = Common::getRequestVar($name, $defaultValue, $type, $this->request);
-                    settype($value, $type);
-                    $filterParameters[] = $value;
-                } catch (Exception $e) {
-                    $exceptionRaised = true;
-                    break;
+                    try {
+                        $value = Common::getRequestVar($name, $defaultValue, $type, $this->request);
+                        settype($value, $type);
+                        $filterParameters[] = $value;
+                    } catch (Exception $e) {
+                        $exceptionRaised = true;
+                        break;
+                    }
                 }
             }
 
