@@ -61,23 +61,28 @@ class Flattener extends DataTableManipulator
      */
     protected function manipulateDataTable($dataTable)
     {
-        // apply filters now since subtables have their filters applied before generic filters. if we don't do this
-        // now, we'll try to apply filters to rows that have already been manipulated. this results in errors like
-        // 'column ... already exists'.
-        $keepFilters = true;
-        if (Common::getRequestVar('disable_queued_filters', 0, 'int', $this->request) == 0) {
-            $dataTable->applyQueuedFilters();
-            $keepFilters = false;
-        }
+        $newDataTable = $dataTable->getEmptyClone($keepFilters = true);
 
-        $newDataTable = $dataTable->getEmptyClone($keepFilters);
-        foreach ($dataTable->getRows() as $rowId => $row) {
-            $this->flattenRow($row, $rowId, $newDataTable);
-        }
+        // this recursive filter will be applied to subtables
+        $dataTable->filter('ReplaceSummaryRowLabel');
+        $dataTable->filter('ReplaceColumnNames');
+
+        $this->flattenDataTableInto($dataTable, $newDataTable);
 
         return $newDataTable;
     }
 
+    /**
+     * @param $dataTable DataTable
+     * @param $newDataTable
+     */
+    protected function flattenDataTableInto($dataTable, $newDataTable, $prefix = '', $logo = false)
+    {
+        foreach ($dataTable->getRows() as $rowId => $row) {
+            $this->flattenRow($row, $rowId, $newDataTable, $prefix, $logo);
+        }
+    }
+
     /**
      * @param Row $row
      * @param DataTable $dataTable
@@ -132,9 +137,7 @@ class Flattener extends DataTableManipulator
                 $dataTable->addRow($row);
             }
             $prefix = $label . $this->recursiveLabelSeparator;
-            foreach ($subTable->getRows() as $rowId => $row) {
-                $this->flattenRow($row, $rowId, $dataTable, $prefix, $logo);
-            }
+            $this->flattenDataTableInto($subTable, $dataTable, $prefix, $logo);
         }
     }
 
@@ -150,4 +153,5 @@ class Flattener extends DataTableManipulator
 
         return $request;
     }
+
 }
