@@ -207,8 +207,16 @@ class Proxy extends Singleton
              */
             Piwik::postEvent(sprintf('API.%s.%s', $pluginName, $methodName), array(&$finalParameters));
 
+            $apiParametersInCorrectOrder = array();
+
+            foreach ($parameterNamesDefaultValues as $name => $defaultValue) {
+                if (isset($finalParameters[$name]) || array_key_exists($name, $finalParameters)) {
+                    $apiParametersInCorrectOrder[] = $finalParameters[$name];
+                }
+            }
+
             // call the method
-            $returnedValue = call_user_func_array(array($object, $methodName), $finalParameters);
+            $returnedValue = call_user_func_array(array($object, $methodName), $apiParametersInCorrectOrder);
 
             $endHookParams = array(
                 &$returnedValue,
@@ -408,7 +416,7 @@ class Proxy extends Singleton
             } catch (Exception $e) {
                 throw new Exception(Piwik::translate('General_PleaseSpecifyValue', array($name)));
             }
-            $finalParameters[] = $requestValue;
+            $finalParameters[$name] = $requestValue;
         }
         return $finalParameters;
     }
