@@ -210,11 +210,22 @@ class Console extends Application
             'Piwik\CliMulti\RequestCommand'
         );
 
-        if (class_exists('Piwik\Plugins\EnterpriseAdmin\EnterpriseAdmin')) {
-            $extra = new \Piwik\Plugins\EnterpriseAdmin\EnterpriseAdmin();
-            $extra->addConsoleCommands($commands);
-        }
+        $commandsFromPluginsMarkedInConfig = $this->getCommandsFromPluginsMarkedInConfig();
+        $commands = array_merge($commands, $commandsFromPluginsMarkedInConfig);
 
         return $commands;
     }
+
+    private function getCommandsFromPluginsMarkedInConfig()
+    {
+        $plugins = Config::getInstance()->General['always_load_commands_from_plugin'];
+        $plugins = explode(',', $plugins);
+
+        $commands = array();
+        foreach($plugins as $plugin) {
+            $instance = new Plugin($plugin);
+            $commands = array_merge($commands, $instance->findMultipleComponents('Commands', 'Piwik\\Plugin\\ConsoleCommand'));
+        }
+        return $commands;
+    }
 }
