@@ -155,9 +155,8 @@ require_once PIWIK_INCLUDE_PATH . "/core/DataTable/Bridges.php";
  *
  *     public function getMyReport($idSite, $period, $date, $segment = false, $expanded = false)
  *     {
- *         $dataTable = Archive::getDataTableFromArchive('MyPlugin_MyReport', $idSite, $period, $date, $segment, $expanded);
+ *         $dataTable = Archive::createDataTableFromArchive('MyPlugin_MyReport', $idSite, $period, $date, $segment, $expanded);
  *         $dataTable->filter('Sort', array(Metrics::INDEX_NB_VISITS, 'desc', $naturalSort = false, $expanded));
- *         $dataTable->queueFilter('ReplaceColumnNames');
  *         $dataTable->queueFilter('ColumnCallbackAddMetadata', array('label', 'url', __NAMESPACE__ . '\getUrlFromLabelForMyReport'));
  *         return $dataTable;
  *     }
@@ -699,6 +698,7 @@ class DataTable implements DataTableInterface, \IteratorAggregate, \ArrayAccess
      */
     public function rebuildIndex()
     {
+        $this->rowsIndexByLabel = array();
         $this->rebuildIndexContinuously = true;
 
         foreach ($this->rows as $id => $row) {
@@ -877,6 +877,14 @@ class DataTable implements DataTableInterface, \IteratorAggregate, \ArrayAccess
         return $this->rows;
     }
 
+    /**
+     * @ignore
+     */
+    public function getRowsCountWithoutSummaryRow()
+    {
+        return count($this->rows);
+    }
+
     /**
      * Returns an array containing all column values for the requested column.
      *
