@@ -1,12 +1,10 @@
 <?php
 /**
- * Piwik - Open source web analytics
+ * Piwik - free/libre analytics platform
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  *
- * @category Piwik
- * @package Piwik
  */
 
 /**
@@ -15,8 +13,8 @@
  */
 namespace {
 
-    use Piwik\DataTable\Row\DataTableSummaryRow;
     use Piwik\DataTable\Row;
+    use Piwik\DataTable\Row\DataTableSummaryRow;
 
     class Piwik_DataTable_Row_DataTableSummary extends DataTableSummaryRow
     {
@@ -26,5 +24,11 @@ namespace {
     {
     }
 
-}
+    // only used for BC to unserialize old archived Row instances. We cannot unserialize Row directly as it implements
+    // the Serializable interface and it would fail on PHP5.6+ when userializing the Row instance directly.
+    class Piwik_DataTable_SerializedRow
+    {
+        public $c;
+    }
 
+}
