@@ -14,6 +14,8 @@ use Piwik\API\Request;
 use Piwik\Container\StaticContainer;
 use Piwik\Exception\AuthenticationFailedException;
 use Piwik\Exception\DatabaseSchemaIsNewerThanCodebaseException;
+use Piwik\Exception\PluginDeactivatedException;
+use Piwik\Exception\StylesheetLessCompileException;
 use Piwik\Http\ControllerResolver;
 use Piwik\Http\Router;
 use Piwik\Plugins\CoreAdminHome\CustomLogo;
@@ -43,14 +45,14 @@ use Piwik\Plugins\CoreAdminHome\CustomLogo;
  *         $_GET['changeVisitAlpha'] = false;
  *         $_GET['removeOldVisits'] = false;
  *         $_GET['showFooterMessage'] = false;
- *         $realtimeMap = FrontController::getInstance()->fetchDispatch('UserCountryMap', 'realtimeMap');
+ *         $realtimeMap = FrontController::getInstance()->dispatch('UserCountryMap', 'realtimeMap');
  *
  *         $view = new View('@MyPlugin/myPopupWithRealtimeMap.twig');
  *         $view->realtimeMap = $realtimeMap;
  *         return $realtimeMap->render();
  *     }
  *
- * For a detailed explanation, see the documentation [here](http://piwik.org/docs/plugins/framework-overview).
+ * For a detailed explanation, see the documentation [here](https://developer.piwik.org/guides/how-piwik-works).
  *
  * @method static \Piwik\FrontController getInstance()
  */
@@ -70,10 +72,46 @@ class FrontController extends Singleton
      */
     private $initialized = false;
 
+    /**
+     * @param $lastError
+     * @return string
+     * @throws AuthenticationFailedException
+     * @throws Exception
+     */
+    private static function generateSafeModeOutputFromError($lastError)
+    {
+        Common::sendResponseCode(500);
+
+        $controller = FrontController::getInstance();
+        try {
+            $controller->init();
+            $message = $controller->dispatch('CorePluginsAdmin', 'safemode', array($lastError));
+        } catch(Exception $e) {
+            // may fail in safe mode (eg. global.ini.php not found)
+            $message = sprintf("Piwik encoutered an error: %s (which lead to: %s)", $lastError['message'], $e->getMessage());
+        }
+
+        return $message;
+    }
+
+    /**
+     * @param Exception $e
+     * @return string
+     */
+    private static function generateSafeModeOutputFromException($e)
+    {
+        $error = array(
+            'message' => $e->getMessage(),
+            'file' => $e->getFile(),
+            'line' => $e->getLine()
+        );
+        return self::generateSafeModeOutputFromError($error);
+    }
+
     /**
      * Executes the requested plugin controller method.
      *
-     * @throws Exception|\Piwik\PluginDeactivatedException in case the plugin doesn't exist, the action doesn't exist,
+     * @throws Exception|\Piwik\Exception\PluginDeactivatedException in case the plugin doesn't exist, the action doesn't exist,
      *                                                     there is not enough permission, etc.
      *
      * @param string $module The name of the plugin whose controller to execute, eg, `'UserCountryMap'`.
@@ -110,6 +148,15 @@ class FrontController extends Singleton
              * @param \Piwik\NoAccessException $exception The exception that was caught.
              */
             Piwik::postEvent('User.isNotAuthorized', array($exception), $pending = true);
+        } catch (\Twig_Error_Runtime $e) {
+            echo $this->generateSafeModeOutputFromException($e);
+            exit;
+        } catch(StylesheetLessCompileException $e) {
+            echo $this->generateSafeModeOutputFromException($e);
+            exit;
+        } catch(\Error $e) {
+            echo $this->generateSafeModeOutputFromException($e);
+            exit;
         }
     }
 
@@ -179,12 +226,7 @@ class FrontController extends Singleton
     {
         $lastError = error_get_last();
         if (!empty($lastError) && $lastError['type'] == E_ERROR) {
-            Common::sendResponseCode(500);
-
-            $controller = FrontController::getInstance();
-            $controller->init();
-            $message = $controller->dispatch('CorePluginsAdmin', 'safemode', array($lastError));
-
+            $message = self::generateSafeModeOutputFromError($lastError);
             echo $message;
         }
     }
@@ -290,7 +332,12 @@ class FrontController extends Singleton
 
         $this->throwIfPiwikVersionIsOlderThanDBSchema();
 
-        \Piwik\Plugin\Manager::getInstance()->installLoadedPlugins();
+        if (empty($_GET['module'])
+            || empty($_GET['action'])
+            || $_GET['module'] !== 'Installation'
+            || !in_array($_GET['action'], array('getInstallationCss', 'getInstallationJs'))) {
+            \Piwik\Plugin\Manager::getInstance()->installLoadedPlugins();
+        }
 
         // ensure the current Piwik URL is known for later use
         if (method_exists('Piwik\SettingsPiwik', 'getPiwikUrl')) {
@@ -386,16 +433,18 @@ class FrontController extends Singleton
         }
         Common::sendResponseCode(503);
 
-        $logoUrl = null;
-        $faviconUrl = null;
+        $logoUrl = 'plugins/Morpheus/images/logo.svg';
+        $faviconUrl = 'plugins/CoreHome/images/favicon.png';
         try {
             $logo = new CustomLogo();
-            $logoUrl = $logo->getHeaderLogoUrl();
+            if ($logo->hasSVGLogo()) {
+                $logoUrl = $logo->getSVGLogoUrl();
+            } else {
+                $logoUrl = $logo->getHeaderLogoUrl();
+            }
             $faviconUrl = $logo->getPathUserFavicon();
         } catch (Exception $ex) {
         }
-        $logoUrl = $logoUrl ?: 'plugins/Morpheus/images/logo-header.png';
-        $faviconUrl = $faviconUrl ?: 'plugins/CoreHome/images/favicon.png';
 
         $page = file_get_contents(PIWIK_INCLUDE_PATH . '/plugins/Morpheus/templates/maintenance.tpl');
         $page = str_replace('%logoUrl%', $logoUrl, $page);
