@@ -15,6 +15,8 @@ use Piwik\Period;
  */
 class Month extends Period
 {
+    const PERIOD_ID = 3;
+
     protected $label = 'month';
 
     /**
@@ -25,7 +27,7 @@ class Month extends Period
     public function getLocalizedShortString()
     {
         //"Aug 09"
-        $out = $this->getDateStart()->getLocalized($this->translator->translate('CoreHome_ShortMonthFormat'));
+        $out = $this->getDateStart()->getLocalized(Date::DATE_FORMAT_MONTH_SHORT);
         return $out;
     }
 
@@ -37,7 +39,7 @@ class Month extends Period
     public function getLocalizedLongString()
     {
         //"August 2009"
-        $out = $this->getDateStart()->getLocalized($this->translator->translate('CoreHome_LongMonthFormat'));
+        $out = $this->getDateStart()->getLocalized(Date::DATE_FORMAT_MONTH_LONG);
         return $out;
     }
 
@@ -111,4 +113,14 @@ class Month extends Period
             $startDate = $startDate->addDay(1);
         }
     }
+
+    public function getImmediateChildPeriodLabel()
+    {
+        return 'week';
+    }
+
+    public function getParentPeriodLabel()
+    {
+        return 'year';
+    }
 }
