@@ -21,19 +21,12 @@ class ConsoleCommand extends SymfonyCommand
 {
     public function writeSuccessMessage(OutputInterface $output, $messages)
     {
-        $lengths = array_map('strlen', $messages);
-        $maxLen = max($lengths) + 4;
-
-        $separator = str_pad('', $maxLen, '*');
-
         $output->writeln('');
-        $output->writeln('<info>' . $separator . '</info>');
 
         foreach ($messages as $message) {
-            $output->writeln('  ' . $message . '  ');
+            $output->writeln('<info>' . $message . '</info>');
         }
 
-        $output->writeln('<info>' . $separator . '</info>');
         $output->writeln('');
     }
 
@@ -46,7 +39,7 @@ class ConsoleCommand extends SymfonyCommand
             $value = $input->getOption($name);
 
             if ($option->isValueRequired() && empty($value)) {
-                throw new \InvalidArgumentException(sprintf('The required option %s is not set', $name));
+                throw new \InvalidArgumentException(sprintf('The required option --%s is not set', $name));
             }
         }
     }
