@@ -14,7 +14,6 @@ use Piwik\Container\StaticContainer;
 use Piwik\Development;
 use Piwik\Menu\MenuAdmin;
 use Piwik\Menu\MenuTop;
-use Piwik\Menu\MenuUser;
 use Piwik\Notification;
 use Piwik\Notification\Manager as NotificationManager;
 use Piwik\Piwik;
@@ -89,13 +88,13 @@ abstract class ControllerAdmin extends Controller
 
     private static function notifyAnyInvalidPlugin()
     {
-        $missingPlugins = \Piwik\Plugin\Manager::getInstance()->getMissingPlugins();
-
-        if (empty($missingPlugins)) {
+        if (!Piwik::hasUserSuperUserAccess()) {
             return;
         }
 
-        if (!Piwik::hasUserSuperUserAccess()) {
+        $missingPlugins = \Piwik\Plugin\Manager::getInstance()->getMissingPlugins();
+
+        if (empty($missingPlugins)) {
             return;
         }
 
@@ -144,10 +143,13 @@ abstract class ControllerAdmin extends Controller
             return;
         }
 
-        if(Url::isLocalHost(Url::getCurrentHost())) {
+        if (Url::isLocalHost(Url::getCurrentHost())) {
             return;
         }
 
+        if (Development::isEnabled()) {
+            return;
+        }
 
         $message = Piwik::translate('General_CurrentlyUsingUnsecureHttp');
 
@@ -215,7 +217,9 @@ abstract class ControllerAdmin extends Controller
 
     private static function notifyWhenPhpVersionIsNotCompatibleWithNextMajorPiwik()
     {
-        if(self::isUsingPhpVersionCompatibleWithNextPiwik()) {
+        return; // no major version coming
+
+        if (self::isUsingPhpVersionCompatibleWithNextPiwik()) {
             return;
         }
 
@@ -234,17 +238,10 @@ abstract class ControllerAdmin extends Controller
         NotificationManager::notify('PHPVersionTooOldForNewestPiwikCheck', $notification);
     }
 
-
     private static function notifyWhenPhpVersionIsEOL()
     {
-        $deprecatedMajorPhpVersion = null;
-        if(self::isPhpVersion53()) {
-            $deprecatedMajorPhpVersion = '5.3';
-        } elseif(self::isPhpVersion54()) {
-            $deprecatedMajorPhpVersion = '5.4';
-        }
-
-        $notifyPhpIsEOL = Piwik::hasUserSuperUserAccess() && $deprecatedMajorPhpVersion;
+        return; // no supported version (5.5+) has currently ended support
+        $notifyPhpIsEOL = Piwik::hasUserSuperUserAccess() && self::isPhpVersionAtLeast55();
         if (!$notifyPhpIsEOL) {
             return;
         }
@@ -259,7 +256,7 @@ abstract class ControllerAdmin extends Controller
         $notification->context = Notification::CONTEXT_WARNING;
         $notification->type = Notification::TYPE_TRANSIENT;
         $notification->flags = Notification::FLAG_NO_CLEAR;
-        NotificationManager::notify('DeprecatedPHPVersionCheck', $notification);
+        NotificationManager::notify('PHP54VersionCheck', $notification);
     }
 
     private static function notifyWhenDebugOnDemandIsEnabled($trackerSetting)
@@ -309,8 +306,7 @@ abstract class ControllerAdmin extends Controller
         self::notifyIfEAcceleratorIsUsed();
         self::notifyIfURLIsNotSecure();
 
-        $view->topMenu  = MenuTop::getInstance()->getMenu();
-        $view->userMenu = MenuUser::getInstance()->getMenu();
+        $view->topMenu = MenuTop::getInstance()->getMenu();
 
         $view->isDataPurgeSettingsEnabled = self::isDataPurgeSettingsEnabled();
         $enableFrames = PiwikConfig::getInstance()->General['enable_framed_settings'];
@@ -329,8 +325,27 @@ abstract class ControllerAdmin extends Controller
         self::notifyWhenDebugOnDemandIsEnabled('debug');
         self::notifyWhenDebugOnDemandIsEnabled('debug_on_demand');
 
-        $adminMenu = MenuAdmin::getInstance()->getMenu();
-        $view->adminMenu = $adminMenu;
+        /**
+         * Posted when rendering an admin page and notifications about any warnings or errors should be triggered.
+         * You can use it for example when you have a plugin that needs to be configured in order to work and the
+         * plugin has not been configured yet. It can be also used to cancel / remove other notifications by calling 
+         * eg `Notification\Manager::cancel($notificationId)`.
+         *
+         * **Example**
+         *
+         *     public function onTriggerAdminNotifications(Piwik\Widget\WidgetsList $list)
+         *     {
+         *         if ($pluginFooIsNotConfigured) {
+         *              $notification = new Notification('The plugin foo has not been configured yet');
+         *              $notification->context = Notification::CONTEXT_WARNING;
+         *              Notification\Manager::notify('fooNotConfigured', $notification);
+         *         }
+         *     }
+         *
+         */
+        Piwik::postEvent('Controller.triggerAdminNotifications');
+
+        $view->adminMenu = MenuAdmin::getInstance()->getMenu();
 
         $notifications = $view->notifications;
 
@@ -350,13 +365,8 @@ abstract class ControllerAdmin extends Controller
         return "Piwik " . Version::VERSION;
     }
 
-    private static function isPhpVersion53()
+    private static function isPhpVersionAtLeast55()
     {
-        return strpos(PHP_VERSION, '5.3') === 0;
-    }
-
-    private static function isPhpVersion54()
-    {
-        return strpos(PHP_VERSION, '5.4') === 0;
+        return version_compare(PHP_VERSION, '5.5', '>=');
     }
 }
