@@ -12,24 +12,26 @@ namespace Piwik\Plugin;
 use Piwik\Application\Kernel\PluginList;
 use Piwik\Cache;
 use Piwik\Columns\Dimension;
-use Piwik\Config as PiwikConfig;
 use Piwik\Config;
+use Piwik\Config as PiwikConfig;
 use Piwik\Container\StaticContainer;
+use Piwik\Db;
 use Piwik\EventDispatcher;
+use Piwik\Exception\PluginDeactivatedException;
 use Piwik\Filesystem;
 use Piwik\Log;
 use Piwik\Notification;
 use Piwik\Piwik;
 use Piwik\Plugin;
-use Piwik\PluginDeactivatedException;
+use Piwik\Plugin\Dimension\ActionDimension;
+use Piwik\Plugin\Dimension\ConversionDimension;
+use Piwik\Plugin\Dimension\VisitDimension;
 use Piwik\Session;
+use Piwik\Settings\Storage as SettingsStorage;
 use Piwik\Theme;
 use Piwik\Tracker;
 use Piwik\Translation\Translator;
 use Piwik\Updater;
-use Piwik\Plugin\Dimension\ActionDimension;
-use Piwik\Plugin\Dimension\ConversionDimension;
-use Piwik\Plugin\Dimension\VisitDimension;
 
 require_once PIWIK_INCLUDE_PATH . '/core/EventDispatcher.php';
 
@@ -398,7 +400,8 @@ class Manager
         }
         $this->loadAllPluginsAndGetTheirInfo();
 
-        \Piwik\Settings\Manager::cleanupPluginSettings($pluginName);
+        SettingsStorage\Backend\PluginSettingsTable::removeAllSettingsForPlugin($pluginName);
+        SettingsStorage\Backend\MeasurableSettingsTable::removeAllSettingsForPlugin($pluginName);
 
         $this->executePluginDeactivate($pluginName);
         $this->executePluginUninstall($pluginName);
@@ -465,7 +468,8 @@ class Manager
     {
         $plugins = $this->pluginList->getActivatedPlugins();
         if (in_array($pluginName, $plugins)) {
-            throw new \Exception("Plugin '$pluginName' already activated.");
+            // plugin is already activated
+            return;
         }
 
         if (!$this->isPluginInFilesystem($pluginName)) {
@@ -498,7 +502,7 @@ class Manager
         Piwik::postEvent('PluginManager.pluginActivated', array($pluginName));
     }
 
-    protected function isPluginInFilesystem($pluginName)
+    public function isPluginInFilesystem($pluginName)
     {
         $existingPlugins = $this->readPluginsDirectory();
         $isPluginInFilesystem = array_search($pluginName, $existingPlugins) !== false;
@@ -550,13 +554,14 @@ class Manager
         throw new \Exception('Theme not found : ' . $themeName);
     }
 
-    public function getNumberOfActivatedPlugins()
+    public function getNumberOfActivatedPluginsExcludingAlwaysActivated()
     {
         $counter = 0;
 
         $pluginNames = $this->getLoadedPluginsName();
         foreach ($pluginNames as $pluginName) {
-            if ($this->isPluginActivated($pluginName)) {
+            if ($this->isPluginActivated($pluginName)
+                && !$this->isPluginAlwaysActivated($pluginName)) {
                 $counter++;
             }
         }
@@ -627,7 +632,7 @@ class Manager
                 'info' => $oPlugin->getInformation(),
                 'activated'       => $this->isPluginActivated($pluginName),
                 'alwaysActivated' => $this->isPluginAlwaysActivated($pluginName),
-                'missingRequirements' => $oPlugin->getMissingDependencies(),
+                'missingRequirements' => $oPlugin->getMissingDependenciesAsString(),
                 'uninstallable' => $this->isPluginUninstallable($pluginName),
             );
             $plugins[$pluginName] = $info;
@@ -819,7 +824,7 @@ class Manager
      */
     public function getLoadedPlugin($name)
     {
-        if (!isset($this->loadedPlugins[$name])) {
+        if (!isset($this->loadedPlugins[$name]) || is_null($this->loadedPlugins[$name])) {
             throw new \Exception("The plugin '$name' has not been loaded.");
         }
         return $this->loadedPlugins[$name];
@@ -844,10 +849,11 @@ class Manager
                 if ($newPlugin->hasMissingDependencies()) {
                     $this->deactivatePlugin($pluginName);
 
-                    // add this state we do not know yet whether current user has super user access. We do not even know
+                    // at this state we do not know yet whether current user has super user access. We do not even know
                     // if someone is actually logged in.
-                    $message  = sprintf('We disabled the plugin %s as it has missing dependencies.', $pluginName);
-                    $message .= ' Please contact your Piwik administrator.';
+                    $message  = Piwik::translate('CorePluginsAdmin_WeDeactivatedThePluginAsItHasMissingDependencies', array($pluginName, $newPlugin->getMissingDependenciesAsString()));
+                    $message .= ' ';
+                    $message .= Piwik::translate('General_PleaseContactYourPiwikAdministrator');
 
                     $notification = new Notification($message);
                     $notification->context = Notification::CONTEXT_ERROR;
@@ -1057,11 +1063,10 @@ class Manager
         $missingPlugins = array();
 
         $plugins = $this->pluginList->getActivatedPlugins();
+
         foreach ($plugins as $pluginName) {
             // if a plugin is listed in the config, but is not loaded, it does not exist in the folder
-            if (!self::getInstance()->isPluginLoaded($pluginName)
-                && !$this->isPluginBogus($pluginName)
-            ) {
+            if (!$this->isPluginLoaded($pluginName) && !$this->isPluginBogus($pluginName) ) {
                 $missingPlugins[] = $pluginName;
             }
         }
