@@ -10,6 +10,7 @@ namespace Piwik\ReportRenderer;
 
 use Piwik\Common;
 use Piwik\Filesystem;
+use Piwik\NumberFormatter;
 use Piwik\Piwik;
 use Piwik\Plugins\API\API;
 use Piwik\ReportRenderer;
@@ -21,7 +22,7 @@ use Piwik\TCPDF;
 require_once PIWIK_INCLUDE_PATH . '/plugins/ScheduledReports/config/tcpdf_config.php';
 
 /**
- *
+ * PDF report renderer
  */
 class Pdf extends ReportRenderer
 {
@@ -64,7 +65,6 @@ class Pdf extends ReportRenderer
     private $tableCellBorderColor;
     private $tableBackgroundColor;
     private $rowTopBottomBorder = array(231, 231, 231);
-    private $report;
     private $reportMetadata;
     private $displayGraph;
     private $evolutionGraph;
@@ -405,7 +405,7 @@ class Pdf extends ReportRenderer
                     if (empty($rowMetrics[$columnId])) {
                         $rowMetrics[$columnId] = 0;
                     }
-                    $this->TCPDF->Cell($this->cellWidth, $this->cellHeight, $rowMetrics[$columnId], 'LR', 0, 'L', $fill);
+                    $this->TCPDF->Cell($this->cellWidth, $this->cellHeight, NumberFormatter::getInstance()->format($rowMetrics[$columnId]), 'LR', 0, 'L', $fill);
                 }
             }
 
