@@ -12,7 +12,6 @@ use Exception;
 use Piwik\Plugins\BulkTracking\Tracker\Requests;
 use Piwik\Plugins\PrivacyManager\Config as PrivacyManagerConfig;
 use Piwik\Config;
-use Piwik\Tests\Framework\TestingEnvironmentVariables;
 use Piwik\Tracker\Db as TrackerDb;
 use Piwik\Tracker\Db\DbException;
 use Piwik\Tracker\Handler;
@@ -24,7 +23,7 @@ use Piwik\Plugin\Manager as PluginManager;
 
 /**
  * Class used by the logging script piwik.php called by the javascript tag.
- * Handles the visitor & his/her actions on the website, saves the data in the DB,
+ * Handles the visitor and their actions on the website, saves the data in the DB,
  * saves information in the cookie, etc.
  *
  * We try to include as little files as possible (no dependency on 3rd party modules).
@@ -77,7 +76,7 @@ class Tracker
             ExceptionHandler::setUp();
 
             Common::printDebug("Debug enabled - Input parameters: ");
-            Common::printDebug(var_export($_GET, true));
+            Common::printDebug(var_export($_GET + $_POST, true));
         }
     }
 
