@@ -234,6 +234,13 @@ abstract class Action
         $this->customFields[$field] = $value;
     }
 
+    public function getCustomField($field)
+    {
+        if (isset($this->customFields[$field])) {
+            return $this->customFields[$field];
+        }
+    }
+
     public function getCustomFields()
     {
         return $this->customFields;
@@ -248,12 +255,12 @@ abstract class Action
 
     public function getIdActionUrlForEntryAndExitIds()
     {
-        return $this->getIdActionUrl();
+        return false;
     }
 
     public function getIdActionNameForEntryAndExitIds()
     {
-        return $this->getIdActionName();
+        return false;
     }
 
     public function getIdActionName()
@@ -400,18 +407,6 @@ abstract class Action
         $visitActionDebug = $visitAction;
         $visitActionDebug['idvisitor'] = bin2hex($visitActionDebug['idvisitor']);
         Common::printDebug($visitActionDebug);
-
-        /**
-         * Triggered after successfully persisting a [visit action entity](/guides/persistence-and-the-mysql-backend#visit-actions).
-         *
-         * This event is deprecated, use [Dimensions](http://developer.piwik.org/guides/dimensions) instead.
-         *
-         * @param Action $tracker Action The Action tracker instance.
-         * @param array $visitAction The visit action entity that was persisted. Read
-         *                           [this](/guides/persistence-and-the-mysql-backend#visit-actions) to see what it contains.
-         * @deprecated
-         */
-        Piwik::postEvent('Tracker.recordAction', array($trackerAction = $this, $visitAction));
     }
 
     public function writeDebugInfo()
