@@ -130,7 +130,7 @@ class GoalManager
         $convertedGoals = array();
         foreach ($goals as $goal) {
             $convertedUrl = $this->detectGoalMatch($goal, $action);
-            if (!empty($convertedUrl)) {
+            if (!is_null($convertedUrl)) {
                 $convertedGoals[] = array('url' => $convertedUrl) + $goal;
             }
         }
@@ -143,7 +143,7 @@ class GoalManager
      *
      * @param array $goal
      * @param Action $action
-     * @return string|null
+     * @return if a goal is matched, a string of the Action URL is returned, or if no goal was matched it returns null
      */
     public function detectGoalMatch($goal, Action $action)
     {
@@ -165,26 +165,26 @@ class GoalManager
         switch ($attribute) {
             case 'title':
                 // Matching on Page Title
-                $url = $action->getActionName();
+                $actionToMatch = $action->getActionName();
                 break;
             case 'event_action':
-                $url = $action->getEventAction();
+                $actionToMatch = $action->getEventAction();
                 break;
             case 'event_name':
-                $url = $action->getEventName();
+                $actionToMatch = $action->getEventName();
                 break;
             case 'event_category':
-                $url = $action->getEventCategory();
+                $actionToMatch = $action->getEventCategory();
                 break;
             // url, external_website, file, manually...
             default:
-                $url = $action->getActionUrlRaw();
+                $actionToMatch = $action->getActionUrlRaw();
                 break;
         }
 
         $pattern_type = $goal['pattern_type'];
 
-        $match = $this->isUrlMatchingGoal($goal, $pattern_type, $url);
+        $match = $this->isUrlMatchingGoal($goal, $pattern_type, $actionToMatch);
         if (!$match) {
             return null;
         }
@@ -336,28 +336,12 @@ class GoalManager
             $recorded = $this->getModel()->updateConversion(
                 $visitProperties->getProperty('idvisit'), self::IDGOAL_CART, $conversion);
         } else {
-            $recorded = $this->insertNewConversion($conversion, $visitProperties->getProperties(), $request);
+            $recorded = $this->insertNewConversion($conversion, $visitProperties->getProperties(), $request, $action);
         }
 
         if ($recorded) {
             $this->recordEcommerceItems($conversion, $items);
         }
-
-        /**
-         * Triggered after successfully persisting an ecommerce conversion.
-         *
-         * _Note: Subscribers should be wary of doing any expensive computation here as it may slow
-         * the tracker down._
-         *
-         * This event is deprecated, use [Dimensions](http://developer.piwik.org/guides/dimensions) instead.
-         *
-         * @param array $conversion The conversion entity that was just persisted. See what information
-         *                          it contains [here](/guides/persistence-and-the-mysql-backend#conversions).
-         * @param array $visitInformation The visit entity that we are tracking a conversion for. See what
-         *                                information it contains [here](/guides/persistence-and-the-mysql-backend#visits).
-         * @deprecated
-         */
-        Piwik::postEvent('Tracker.recordEcommerceGoal', array($conversion, $visitProperties->getProperties()));
     }
 
     /**
@@ -692,21 +676,7 @@ class GoalManager
             $conversionDimensions = ConversionDimension::getAllDimensions();
             $conversion = $this->triggerHookOnDimensions($request, $conversionDimensions, 'onGoalConversion', $visitor, $action, $conversion);
 
-            $this->insertNewConversion($conversion, $visitProperties->getProperties(), $request);
-
-            /**
-             * Triggered after successfully recording a non-ecommerce conversion.
-             *
-             * _Note: Subscribers should be wary of doing any expensive computation here as it may slow
-             * the tracker down._
-             *
-             * This event is deprecated, use [Dimensions](http://developer.piwik.org/guides/dimensions) instead.
-             *
-             * @param array $conversion The conversion entity that was just persisted. See what information
-             *                          it contains [here](/guides/persistence-and-the-mysql-backend#conversions).
-             * @deprecated
-             */
-            Piwik::postEvent('Tracker.recordStandardGoals', array($conversion));
+            $this->insertNewConversion($conversion, $visitProperties->getProperties(), $request, $action);
         }
     }
 
@@ -715,9 +685,11 @@ class GoalManager
      *
      * @param array $conversion
      * @param array $visitInformation
+     * @param Request $request
+     * @param Action|null $action
      * @return bool
      */
-    protected function insertNewConversion($conversion, $visitInformation, Request $request)
+    protected function insertNewConversion($conversion, $visitInformation, Request $request, $action)
     {
         /**
          * Triggered before persisting a new [conversion entity](/guides/persistence-and-the-mysql-backend#conversions).
@@ -731,9 +703,12 @@ class GoalManager
          * @param array $visitInformation The visit entity that we are tracking a conversion for. See what
          *                                information it contains [here](/guides/persistence-and-the-mysql-backend#visits).
          * @param \Piwik\Tracker\Request $request An object describing the tracking request being processed.
+         * @param Action|null $action An action object like ActionPageView or ActionDownload, or null if no action is
+         *                            supposed to be processed.
          * @deprecated
+         * @ignore
          */
-        Piwik::postEvent('Tracker.newConversionInformation', array(&$conversion, $visitInformation, $request));
+        Piwik::postEvent('Tracker.newConversionInformation', array(&$conversion, $visitInformation, $request, $action));
 
         $newGoalDebug = $conversion;
         $newGoalDebug['idvisitor'] = bin2hex($newGoalDebug['idvisitor']);
