@@ -21,11 +21,6 @@ class UpdateCheck
     const LATEST_VERSION = 'UpdateCheck_LatestVersion';
     const SOCKET_TIMEOUT = 2;
 
-    private static function isAutoUpdateEnabled()
-    {
-        return (bool) Config::getInstance()->General['enable_auto_update'];
-    }
-
     /**
      * Check for a newer version
      *
@@ -34,7 +29,7 @@ class UpdateCheck
      */
     public static function check($force = false, $interval = null)
     {
-        if (!self::isAutoUpdateEnabled()) {
+        if (!SettingsPiwik::isAutoUpdateEnabled()) {
             return;
         }
 
@@ -68,7 +63,8 @@ class UpdateCheck
      */
     private static function getLatestAvailableVersionNumber()
     {
-        $channel = StaticContainer::get('\Piwik\Plugin\ReleaseChannels')->getActiveReleaseChannel();
+        $releaseChannels = StaticContainer::get('\Piwik\Plugin\ReleaseChannels');
+        $channel = $releaseChannels->getActiveReleaseChannel();
         $url = $channel->getUrlToCheckForLatestAvailableVersion();
 
         try {
