@@ -10,11 +10,12 @@
 namespace Piwik\ViewDataTable;
 
 use Piwik\API\Request as ApiRequest;
+use Piwik\Common;
 use Piwik\DataTable;
 use Piwik\DataTable\Filter\PivotByDimension;
 use Piwik\Metrics;
-use Piwik\Plugin\Report;
 use Piwik\Plugins\API\API;
+use Piwik\Plugin\ReportsProvider;
 
 /**
  * Contains base display properties for {@link Piwik\Plugin\ViewDataTable}s. Manipulating these
@@ -106,7 +107,6 @@ class Config
         'show_footer',
         'show_footer_icons',
         'show_all_views_icons',
-        'show_active_view_icon',
         'show_related_reports',
         'show_limit_control',
         'show_search',
@@ -253,11 +253,6 @@ class Config
      */
     public $show_all_views_icons = true;
 
-    /**
-     * Controls whether to display a tiny upside-down caret over the currently active view icon.
-     */
-    public $show_active_view_icon = true;
-
     /**
      * Related reports are listed below a datatable view. When clicked, the original report will
      * change to the clicked report and the list will change so the original report can be
@@ -279,6 +274,19 @@ class Config
      */
     public $title = '';
 
+    /**
+     * If a URL is set, the title of the report will be clickable. Is supposed to be set for entities that can be
+     * configured (edited) such as goal. Eg when there is a goal report, and someone is allowed to edit the goal entity,
+     * a link is supposed to be with a URL to the edit goal form.
+     * @var string
+     */
+    public $title_edit_entity_url = '';
+
+    /**
+     * The report description. eg like a goal description
+     */
+    public $description = '';
+
     /**
      * Controls whether a report's related reports are listed with the view or not.
      */
@@ -332,6 +340,19 @@ class Config
      */
     public $show_tag_cloud = true;
 
+    /**
+     * If enabled, shows the visualization as a content block. This is similar to wrapping your visualization
+     * with a `<div piwik-content-block></div>`
+     * @var bool
+     */
+    public $show_as_content_block = true;
+
+    /**
+     * If enabled shows the title of the report.
+     * @var bool
+     */
+    public $show_title = true;
+
     /**
      * Controls whether the user is allowed to export data as an RSS feed or not.
      */
@@ -466,6 +487,8 @@ class Config
             Metrics::getDefaultMetrics(),
             Metrics::getDefaultProcessedMetrics()
         );
+
+        $this->show_title = (bool)Common::getRequestVar('showtitle', 0, 'int');
     }
 
     /**
@@ -479,6 +502,7 @@ class Config
 
         $this->loadDocumentation();
         $this->setShouldShowPivotBySubtable();
+        $this->setShouldShowFlattener();
     }
 
     /** Load documentation from the API */
@@ -486,7 +510,28 @@ class Config
     {
         $this->metrics_documentation = array();
 
-        $report = API::getInstance()->getMetadata(0, $this->controllerName, $this->controllerAction);
+        $idSite = Common::getRequestVar('idSite', 0, 'int');
+
+        if ($idSite < 1) {
+            return;
+        }
+
+        $apiParameters = array();
+        $idDimension = Common::getRequestVar('idDimension', 0, 'int');
+        $idGoal = Common::getRequestVar('idGoal', 0, 'int');
+        if ($idDimension > 0) {
+            $apiParameters['idDimension'] = $idDimension;
+        }
+        if ($idGoal > 0) {
+            $apiParameters['idGoal'] = $idGoal;
+        }
+
+        $report = API::getInstance()->getMetadata($idSite, $this->controllerName, $this->controllerAction, $apiParameters);
+
+        if (empty($report)) {
+            return;
+        }
+
         $report = $report[0];
 
         if (isset($report['metricsDocumentation'])) {
@@ -556,6 +601,17 @@ class Config
         $this->columns_to_display = array_filter($columnsToDisplay);
     }
 
+    public function removeColumnToDisplay($columnToRemove)
+    {
+        if (!empty($this->columns_to_display)) {
+
+            $key = array_search($columnToRemove, $this->columns_to_display);
+            if (false !== $key) {
+                unset($this->columns_to_display[$key]);
+            }
+        }
+    }
+
     /**
      * @ignore
      */
@@ -684,7 +740,7 @@ class Config
 
     private function setShouldShowPivotBySubtable()
     {
-        $report = Report::factory($this->controllerName, $this->controllerAction);
+        $report = ReportsProvider::factory($this->controllerName, $this->controllerAction);
 
         if (empty($report)) {
             $this->show_pivot_by_subtable = false;
@@ -700,6 +756,15 @@ class Config
         }
     }
 
+    private function setShouldShowFlattener()
+    {
+        $report = ReportsProvider::factory($this->controllerName, $this->controllerAction);
+
+        if ($report && !$report->supportsFlatten()) {
+            $this->show_flatten_table = false;
+        }
+    }
+
     public function disablePivotBySubtableIfTableHasNoSubtables(DataTable $table)
     {
         foreach ($table->getRows() as $row) {
