@@ -10,7 +10,7 @@
 #
 # For more info see: http://piwik.org/log-analytics/ and http://piwik.org/docs/log-analytics-tool-how-to/
 #
-# Requires Python 2.6 or greater.
+# Requires Python 2.6 or 2.7
 #
 
 import base64
@@ -70,6 +70,7 @@ DOWNLOAD_EXTENSIONS = set((
 ).split())
 
 # A good source is: http://phpbb-bots.blogspot.com/
+# user agents must be lowercase
 EXCLUDED_USER_AGENTS = (
     'adsbot-google',
     'ask jeeves',
@@ -90,6 +91,7 @@ EXCLUDED_USER_AGENTS = (
     'msnbot',
     'netcraftsurvey',
     'panopta',
+    'pingdom.com_bot_',
     'robot',
     'spider',
     'surveybot',
@@ -988,6 +990,9 @@ class Configuration(object):
             command.append('--piwik-domain=' + hostname )
 
             command = subprocess.list2cmdline(command)
+
+#            logging.debug(command);
+
             process = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
             [stdout, stderr] = process.communicate()
             if process.returncode != 0:
@@ -1341,7 +1346,14 @@ class Piwik(object):
                     final_args.append(('%s[%d]' % (key, index), obj))
             else:
                 final_args.append((key, value))
+
+
+#        logging.debug('%s' % final_args)
+#        logging.debug('%s' % url)
+
         res = Piwik._call('/', final_args, url=url)
+
+
         try:
             return json.loads(res)
         except ValueError:
