@@ -10,7 +10,9 @@ namespace Piwik\Plugins\API;
 
 use Piwik\API\Proxy;
 use Piwik\API\Request;
-use Piwik\Columns\Dimension;
+use Piwik\Cache;
+use Piwik\CacheId;
+use Piwik\Category\CategoryList;
 use Piwik\Common;
 use Piwik\Config;
 use Piwik\Container\StaticContainer;
@@ -23,11 +25,14 @@ use Piwik\Metrics;
 use Piwik\Period;
 use Piwik\Period\Range;
 use Piwik\Piwik;
+use Piwik\Plugin\SettingsProvider;
 use Piwik\Plugins\API\DataTable\MergeDataTables;
 use Piwik\Plugins\CoreAdminHome\CustomLogo;
+use Piwik\Plugins\CorePluginsAdmin\SettingsMetadata;
 use Piwik\Translation\Translator;
 use Piwik\Measurable\Type\TypeManager;
 use Piwik\Version;
+use Piwik\Widget\WidgetsList;
 
 require_once PIWIK_INCLUDE_PATH . '/core/Config.php';
 
@@ -51,6 +56,22 @@ require_once PIWIK_INCLUDE_PATH . '/core/Config.php';
  */
 class API extends \Piwik\Plugin\API
 {
+    /**
+     * @var SettingsProvider
+     */
+    private $settingsProvider;
+
+    /**
+     * @var ProcessedReport
+     */
+    private $processedReport;
+
+    public function __construct(SettingsProvider $settingsProvider, ProcessedReport $processedReport)
+    {
+        $this->settingsProvider = $settingsProvider;
+        $this->processedReport = $processedReport;
+    }
+
     /**
      * Get Piwik version
      * @return string
@@ -62,7 +83,7 @@ class API extends \Piwik\Plugin\API
     }
 
     /**
-     * Returns the most accurate IP address availble for the current user, in
+     * Returns the most accurate IP address available for the current user, in
      * IPv4 format. This could be the proxy client's IP address.
      *
      * @return string IP address in presentation format.
@@ -110,11 +131,16 @@ class API extends \Piwik\Plugin\API
 
         $available = array();
         foreach ($types as $type) {
+            $measurableSettings = $this->settingsProvider->getAllMeasurableSettings($idSite = 0, $type->getId());
+
+            $settingsMetadata = new SettingsMetadata();
+
             $available[] = array(
                 'id' => $type->getId(),
                 'name' => Piwik::translate($type->getName()),
                 'description' => Piwik::translate($type->getDescription()),
-                'howToSetupUrl' => $type->getHowToSetupUrl()
+                'howToSetupUrl' => $type->getHowToSetupUrl(),
+                'settings' => $settingsMetadata->formatSettings($measurableSettings)
             );
         }
 
@@ -131,83 +157,20 @@ class API extends \Piwik\Plugin\API
 
         $isNotAnonymous = !Piwik::isUserIsAnonymous();
 
-        $segments = array();
-        foreach (Dimension::getAllDimensions() as $dimension) {
-            foreach ($dimension->getSegments() as $segment) {
-                if ($segment->isRequiresAtLeastViewAccess()) {
-                    $segment->setPermission($isNotAnonymous);
-                }
+        $sites   = (is_array($idSites) ? implode('.', $idSites) : (int) $idSites);
+        $cache   = Cache::getTransientCache();
+        $cachKey = 'API.getSegmentsMetadata' . $sites . '_' . (int) $_hideImplementationData . '_' . (int) $isNotAnonymous;
+        $cachKey = CacheId::pluginAware($cachKey);
 
-                $segments[] = $segment->toArray();
-            }
+        if ($cache->contains($cachKey)) {
+            return $cache->fetch($cachKey);
         }
 
-        /**
-         * Triggered when gathering all available segment dimensions.
-         *
-         * This event can be used to make new segment dimensions available.
-         *
-         * **Example**
-         *
-         *     public function getSegmentsMetadata(&$segments, $idSites)
-         *     {
-         *         $segments[] = array(
-         *             'type'           => 'dimension',
-         *             'category'       => Piwik::translate('General_Visit'),
-         *             'name'           => 'General_VisitorIP',
-         *             'segment'        => 'visitIp',
-         *             'acceptedValues' => '13.54.122.1, etc.',
-         *             'sqlSegment'     => 'log_visit.location_ip',
-         *             'sqlFilter'      => array('Piwik\IP', 'P2N'),
-         *             'permission'     => $isAuthenticatedWithViewAccess,
-         *         );
-         *     }
-         *
-         * @param array &$dimensions The list of available segment dimensions. Append to this list to add
-         *                           new segments. Each element in this list must contain the
-         *                           following information:
-         *
-         *                           - **type**: Either `'metric'` or `'dimension'`. `'metric'` means
-         *                                       the value is a numeric and `'dimension'` means it is
-         *                                       a string. Also, `'metric'` values will be displayed
-         *                                       under **Visit (metrics)** in the Segment Editor.
-         *                           - **category**: The segment category name. This can be an existing
-         *                                           segment category visible in the segment editor.
-         *                           - **name**: The pretty name of the segment. Can be a translation token.
-         *                           - **segment**: The segment name, eg, `'visitIp'` or `'searches'`.
-         *                           - **acceptedValues**: A string describing one or two exacmple values, eg
-         *                                                 `'13.54.122.1, etc.'`.
-         *                           - **sqlSegment**: The table column this segment will segment by.
-         *                                             For example, `'log_visit.location_ip'` for the
-         *                                             **visitIp** segment.
-         *                           - **sqlFilter**: A PHP callback to apply to segment values before
-         *                                            they are used in SQL.
-         *                           - **permission**: True if the current user has view access to this
-         *                                             segment, false if otherwise.
-         * @param array $idSites The list of site IDs we're getting the available segments
-         *                       for. Some segments (such as Goal segments) depend on the
-         *                       site.
-         */
-        Piwik::postEvent('API.getSegmentDimensionMetadata', array(&$segments, $idSites));
+        $metadata = new SegmentMetadata();
+        $segments = $metadata->getSegmentsMetadata($idSites, $_hideImplementationData, $isNotAnonymous);
 
-        foreach ($segments as &$segment) {
-            $segment['name'] = Piwik::translate($segment['name']);
-            $segment['category'] = Piwik::translate($segment['category']);
+        $cache->save($cachKey, $segments);
 
-            if ($_hideImplementationData) {
-                unset($segment['sqlFilter']);
-                unset($segment['sqlFilterValue']);
-                unset($segment['sqlSegment']);
-
-                if (isset($segment['suggestedValuesCallback'])
-                    && !is_string($segment['suggestedValuesCallback'])
-                ) {
-                    unset($segment['suggestedValuesCallback']);
-                }
-            }
-        }
-
-        usort($segments, array($this, 'sortSegments'));
         return $segments;
     }
 
@@ -228,32 +191,6 @@ class API extends \Piwik\Plugin\API
         return $values;
     }
 
-    private function sortSegments($row1, $row2)
-    {
-        $customVarCategory = Piwik::translate('CustomVariables_CustomVariables');
-
-        $columns = array('type', 'category', 'name', 'segment');
-        foreach ($columns as $column) {
-            // Keep segments ordered alphabetically inside categories..
-            $type = -1;
-            if ($column == 'name') $type = 1;
-
-            $compare = $type * strcmp($row1[$column], $row2[$column]);
-
-            // hack so that custom variables "page" are grouped together in the doc
-            if ($row1['category'] == $customVarCategory
-                && $row1['category'] == $row2['category']
-            ) {
-                $compare = strcmp($row1['segment'], $row2['segment']);
-                return $compare;
-            }
-            if ($compare != 0) {
-                return $compare;
-            }
-        }
-        return $compare;
-    }
-
     /**
      * Returns the url to application logo (~280x110px)
      *
@@ -319,8 +256,7 @@ class API extends \Piwik\Plugin\API
             $translator->setCurrentLanguage($language);
         }
 
-        $reporter = new ProcessedReport();
-        $metadata = $reporter->getMetadata($idSite, $apiModule, $apiAction, $apiParameters, $language, $period, $date, $hideMetricsDoc, $showSubtableReports);
+        $metadata = $this->processedReport->getMetadata($idSite, $apiModule, $apiAction, $apiParameters, $language, $period, $date, $hideMetricsDoc, $showSubtableReports);
         return $metadata;
     }
 
@@ -328,20 +264,30 @@ class API extends \Piwik\Plugin\API
      * Triggers a hook to ask plugins for available Reports.
      * Returns metadata information about each report (category, name, dimension, metrics, etc.)
      *
-     * @param string $idSites Comma separated list of website Ids
+     * @param string $idSites THIS PARAMETER IS DEPRECATED AND WILL BE REMOVED IN PIWIK 4
      * @param bool|string $period
      * @param bool|Date $date
      * @param bool $hideMetricsDoc
      * @param bool $showSubtableReports
+     * @param int $idSite
      * @return array
      */
     public function getReportMetadata($idSites = '', $period = false, $date = false, $hideMetricsDoc = false,
-                                      $showSubtableReports = false)
+                                      $showSubtableReports = false, $idSite = false)
     {
-        Piwik::checkUserHasViewAccess($idSites);
+        if (empty($idSite) && !empty($idSites)) {
+            if (is_array($idSites)) {
+                $idSite = array_shift($idSites);
+            } else {
+                $idSite = $idSites;
+            }
+        } elseif (empty($idSite) && empty($idSites)) {
+            throw new \Exception('Calling API.getReportMetadata without any idSite is no longer supported since Piwik 3.0.0. Please specifiy at least one idSite via the "idSite" parameter.');
+        }
 
-        $reporter = new ProcessedReport();
-        $metadata = $reporter->getReportMetadata($idSites, $period, $date, $hideMetricsDoc, $showSubtableReports);
+        Piwik::checkUserHasViewAccess($idSite);
+
+        $metadata = $this->processedReport->getReportMetadata($idSite, $period, $date, $hideMetricsDoc, $showSubtableReports);
         return $metadata;
     }
 
@@ -352,13 +298,47 @@ class API extends \Piwik\Plugin\API
     {
         Piwik::checkUserHasViewAccess($idSite);
 
-        $reporter = new ProcessedReport();
-        $processed = $reporter->getProcessedReport($idSite, $period, $date, $apiModule, $apiAction, $segment,
+        $processed = $this->processedReport->getProcessedReport($idSite, $period, $date, $apiModule, $apiAction, $segment,
             $apiParameters, $idGoal, $language, $showTimer, $hideMetricsDoc, $idSubtable, $showRawMetrics, $format_metrics, $idDimension);
 
         return $processed;
     }
 
+    /**
+     * Get a list of all pages that shall be shown in a Piwik UI including a list of all widgets that shall
+     * be shown within each page.
+     *
+     * @param int $idSite
+     * @return array
+     */
+    public function getReportPagesMetadata($idSite)
+    {
+        Piwik::checkUserHasViewAccess($idSite);
+
+        $widgetsList  = WidgetsList::get();
+        $categoryList = CategoryList::get();
+        $metadata     = new WidgetMetadata();
+
+        return $metadata->getPagesMetadata($categoryList, $widgetsList);
+    }
+
+    /**
+     * Get a list of all widgetizable widgets.
+     *
+     * @param int $idSite
+     * @return array
+     */
+    public function getWidgetMetadata($idSite)
+    {
+        Piwik::checkUserHasViewAccess($idSite);
+
+        $widgetsList  = WidgetsList::get();
+        $categoryList = CategoryList::get();
+        $metadata     = new WidgetMetadata();
+
+        return $metadata->getWidgetMetadata($categoryList, $widgetsList);
+    }
+
     /**
      * Get a combined report of the *.get API methods.
      */
@@ -458,16 +438,6 @@ class API extends \Piwik\Plugin\API
             $language, $idGoal, $legendAppendMetric, $labelUseAbsoluteUrl, $idDimension);
     }
 
-    /**
-     * @deprecated
-     */
-    public function getLastDate($date, $period)
-    {
-        $lastDate = Range::getLastDate($date, $period);
-
-        return array_shift($lastDate);
-    }
-
     /**
      * Performs multiple API requests at once and returns every result.
      *
@@ -674,9 +644,9 @@ class API extends \Piwik\Plugin\API
     {
         // If you update this, also update flattenVisitorDetailsArray
         $segmentsNeedActionsInfo = array('visitConvertedGoalId',
-                                         'pageUrl', 'pageTitle', 'siteSearchKeyword',
-                                         'entryPageTitle', 'entryPageUrl', 'exitPageTitle', 'exitPageUrl',
-                                         'outlinkUrl', 'downloadUrl'
+            'pageUrl', 'pageTitle', 'siteSearchKeyword',
+            'entryPageTitle', 'entryPageUrl', 'exitPageTitle', 'exitPageUrl',
+            'outlinkUrl', 'downloadUrl'
         );
         $isCustomVariablePage = stripos($segmentName, 'customVariablePage') !== false;
         $isEventSegment = stripos($segmentName, 'event') !== false;
