@@ -16,6 +16,7 @@ use Piwik\Config;
 use Piwik\Piwik;
 use Piwik\Plugin\Report;
 use Piwik\Url;
+use Piwik\UrlHelper;
 use Piwik\View;
 
 /**
@@ -29,8 +30,11 @@ class Controller extends \Piwik\Plugin\Controller
 
         // when calling the API through http, we limit the number of returned results
         if (!isset($_GET['filter_limit'])) {
-            $_GET['filter_limit'] = Config::getInstance()->General['API_datatable_default_limit'];
-            $token .= '&api_datatable_default_limit=' . $_GET['filter_limit'];
+            if (isset($_POST['filter_limit'])) {
+                $_GET['filter_limit'] = $_POST['filter_limit'];
+            } else {
+                $_GET['filter_limit'] = Config::getInstance()->General['API_datatable_default_limit'];
+            }
         }
 
         $request  = new Request($token);
@@ -46,7 +50,11 @@ class Controller extends \Piwik\Plugin\Controller
     public function listAllMethods()
     {
         $ApiDocumentation = new DocumentationGenerator();
-        return $ApiDocumentation->getAllInterfaceString($outputExampleUrls = true, $prefixUrls = Common::getRequestVar('prefixUrl', ''));
+        $prefixUrls = Common::getRequestVar('prefixUrl', 'http://demo.piwik.org/', 'string');
+        if (!UrlHelper::isLookLikeUrl($prefixUrls)) {
+            $prefixUrls = '';
+        }
+        return $ApiDocumentation->getApiDocumentationAsStringForDeveloperReference($outputExampleUrls = true, $prefixUrls);
     }
 
     public function listAllAPI()
@@ -56,7 +64,7 @@ class Controller extends \Piwik\Plugin\Controller
 
         $ApiDocumentation = new DocumentationGenerator();
         $view->countLoadedAPI = Proxy::getInstance()->getCountRegisteredClasses();
-        $view->list_api_methods_with_links = $ApiDocumentation->getAllInterfaceString();
+        $view->list_api_methods_with_links = $ApiDocumentation->getApiDocumentationAsString();
         return $view->render();
     }
 
