@@ -22,6 +22,7 @@ use Piwik\Plugins\Actions\Columns\Metrics\BounceRate;
 use Piwik\Plugins\Actions\Columns\Metrics\ExitRate;
 use Piwik\Plugins\CustomVariables\API as APICustomVariables;
 use Piwik\Plugins\Actions\Actions\ActionSiteSearch;
+use Piwik\Plugin\ReportsProvider;
 use Piwik\Tracker\Action;
 use Piwik\Tracker\PageUrl;
 
@@ -55,7 +56,7 @@ class API extends \Piwik\Plugin\API
     {
         Piwik::checkUserHasViewAccess($idSite);
 
-        $report = Report::factory("Actions", "get");
+        $report = ReportsProvider::factory("Actions", "get");
         $archive = Archive::build($idSite, $period, $date, $segment);
 
         $requestedColumns = Piwik::getArrayFromApiParameter($columns);
@@ -221,7 +222,7 @@ class API extends \Piwik\Plugin\API
     public function getDownloads($idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false, $flat = false)
     {
         $dataTable = Archive::createDataTableFromArchive('Actions_downloads', $idSite, $period, $date, $segment, $expanded, $flat, $idSubtable);
-        $this->filterActionsDataTable($dataTable, $expanded);
+        $this->filterActionsDataTable($dataTable);
         return $dataTable;
     }
 
@@ -236,7 +237,7 @@ class API extends \Piwik\Plugin\API
     public function getOutlinks($idSite, $period, $date, $segment = false, $expanded = false, $idSubtable = false, $flat = false)
     {
         $dataTable = Archive::createDataTableFromArchive('Actions_outlink', $idSite, $period, $date, $segment, $expanded, $flat, $idSubtable);
-        $this->filterActionsDataTable($dataTable, $expanded);
+        $this->filterActionsDataTable($dataTable);
         return $dataTable;
     }
 
