@@ -11,6 +11,7 @@ namespace Piwik\Plugins\Actions\Reports;
 use Piwik\Piwik;
 use Piwik\Plugin\ViewDataTable;
 use Piwik\Plugins\Actions\Columns\DestinationPage;
+use Piwik\Plugin\ReportsProvider;
 
 class GetPageUrlsFollowingSiteSearch extends GetPageTitlesFollowingSiteSearch
 {
@@ -20,8 +21,9 @@ class GetPageUrlsFollowingSiteSearch extends GetPageTitlesFollowingSiteSearch
         $this->dimension     = new DestinationPage();
         $this->name          = Piwik::translate('Actions_WidgetPageUrlsFollowingSearch');
         $this->documentation = Piwik::translate('Actions_SiteSearchFollowingPagesDoc') . '<br/>' . Piwik::translate('General_UsePlusMinusIconsDocumentation');
-        $this->order = 18;
-        $this->widgetTitle  = 'Actions_WidgetPageUrlsFollowingSearch';
+        $this->order = 16;
+
+        $this->subcategoryId = 'Actions_SubmenuSitesearch';
     }
 
     public function configureView(ViewDataTable $view)
@@ -34,7 +36,7 @@ class GetPageUrlsFollowingSiteSearch extends GetPageTitlesFollowingSiteSearch
     public function getRelatedReports()
     {
         return array(
-            self::factory('Actions', 'getPageTitlesFollowingSiteSearch'),
+            ReportsProvider::factory('Actions', 'getPageTitlesFollowingSiteSearch'),
         );
     }
 }
