@@ -81,15 +81,14 @@
                     self.dataTableLoaded(response, self.workingDivId);
                 };
 
-                self.handleSearchBox(domElem, dataTableLoadedProxy);
                 self.handleConfigurationBox(domElem, dataTableLoadedProxy);
+                self.handleSearchBox(domElem, dataTableLoadedProxy);
             }
 
             self.handleColumnDocumentation(domElem);
             self.handleRelatedReports(domElem);
             self.handleTriggeredEvents(domElem);
             self.handleCellTooltips(domElem);
-            self.handleExpandFooter(domElem);
             self.setFixWidthToMakeEllipsisWork(domElem);
             self.handleSummaryRow(domElem);
             self.openSubtableFromLevel0IfOnlyOneSubtableGiven(domElem);
@@ -303,6 +302,8 @@
 
             content.trigger('piwik:dataTableLoaded');
 
+            piwikHelper.compileAngularComponents(content);
+
             piwikHelper.lazyScrollTo(content[0], 400);
 
             return content;
