@@ -79,6 +79,8 @@ CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage
 CoreUpdater_ViewVersionChangelog
 http://piwik.org/changelog/piwik-33-0-0/
 
+CoreUpdater_ReceiveEmailBecauseIsSuperUser
+
 CoreUpdater_FeedbackRequest
 http://piwik.org/contact/";
 
@@ -95,6 +97,8 @@ CoreUpdater_ThereIsNewVersionAvailableForUpdate
 CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage
 {$rootUrl}index.php?module=CoreUpdater&action=newVersionAvailable
 
+CoreUpdater_ReceiveEmailBecauseIsSuperUser
+
 CoreUpdater_FeedbackRequest
 http://piwik.org/contact/";
 
@@ -141,6 +145,8 @@ http://piwik.org/contact/";
      */
     private function getCommunicationMock($methodsToOverwrite)
     {
-        return $this->getMock('\Piwik\Plugins\CoreUpdater\UpdateCommunication', $methodsToOverwrite);
+        return $this->getMockBuilder('\Piwik\Plugins\CoreUpdater\UpdateCommunication')
+                    ->setMethods($methodsToOverwrite)
+                    ->getMock();
     }
 }
