@@ -14,11 +14,12 @@ class CustomVariableName extends Base
 {
     protected function configureSegments()
     {
-        $this->configureSegmentsFor('custom_var_k', 'Name');
+        $this->configureSegmentsFor('Name');
     }
 
     public function getName()
     {
         return Piwik::translate('CustomVariables_ColumnCustomVariableName');
     }
+
 }
\ No newline at end of file
