@@ -21,6 +21,12 @@ use Piwik\Plugins\CoreVisualizations\Visualizations\HtmlTable;
  */
 class GetIndividualReportsSummary extends Base
 {
+
+    protected function init()
+    {
+        $this->name = Piwik::translate('General_Reports');
+    }
+
     public function configureView(ViewDataTable $view)
     {
         $this->addBaseDisplayProperties($view);
