@@ -28,7 +28,7 @@ class Tasks extends \Piwik\Plugin\Tasks
         $api->getIndividualReportsSummary(true);
         $api->getIndividualMetricsSummary(true);
 
-        $now = Date::now()->getLocalized("%longYear%, %shortMonth% %day%");
+        $now = Date::now()->getLocalized(Date::DATE_FORMAT_SHORT);
         Option::set(DBStats::TIME_OF_LAST_TASK_RUN_OPTION, $now);
     }
 }
\ No newline at end of file
