@@ -10,17 +10,17 @@ namespace Piwik\Plugins\Dashboard;
 
 use Piwik\Common;
 use Piwik\Container\StaticContainer;
-use Piwik\Db;
 use Piwik\Piwik;
+use Piwik\Category\Subcategory;
+use Piwik\Widget\WidgetConfig;
 use Piwik\Plugin;
-use Piwik\WidgetsList;
 
 /**
  */
 class Dashboard extends \Piwik\Plugin
 {
     /**
-     * @see Piwik\Plugin::registerEvents
+     * @see \Piwik\Plugin::registerEvents
      */
     public function registerEvents()
     {
@@ -28,10 +28,81 @@ class Dashboard extends \Piwik\Plugin
             'AssetManager.getJavaScriptFiles'        => 'getJsFiles',
             'AssetManager.getStylesheetFiles'        => 'getStylesheetFiles',
             'UsersManager.deleteUser'                => 'deleteDashboardLayout',
-            'Translate.getClientSideTranslationKeys' => 'getClientSideTranslationKeys'
+            'Translate.getClientSideTranslationKeys' => 'getClientSideTranslationKeys',
+            'Widget.addWidgetConfigs'                => 'addWidgetConfigs',
+            'Category.addSubcategories'              => 'addSubcategories'
         );
     }
 
+    public function addWidgetConfigs(&$widgets)
+    {
+        if (Piwik::isUserIsAnonymous()) {
+            $this->addDefaultDashboard($widgets);
+        } else {
+            $dashboards = API::getInstance()->getDashboards();
+
+            if (empty($dashboards)) {
+                $this->addDefaultDashboard($widgets);
+            } else {
+                foreach ($dashboards as $dashboard) {
+                    $config = new WidgetConfig();
+                    $config->setIsNotWidgetizable();
+                    $config->setModule('Dashboard');
+                    $config->setAction('embeddedIndex');
+                    $config->setCategoryId('Dashboard_Dashboard');
+                    $config->setSubcategoryId($dashboard['id']);
+                    $config->setParameters(array('idDashboard' => $dashboard['id']));
+                    $widgets[] = $config;
+                }
+            }
+        }
+    }
+
+    private function addDefaultDashboard(&$widgets)
+    {
+        $config = new WidgetConfig();
+        $config->setIsNotWidgetizable();
+        $config->setModule('Dashboard');
+        $config->setAction('embeddedIndex');
+        $config->setCategoryId('Dashboard_Dashboard');
+        $config->setSubcategoryId('1');
+        $config->setParameters(array('idDashboard' => 1));
+        $widgets[] = $config;
+    }
+
+    public function addSubcategories(&$subcategories)
+    {
+        if (Piwik::isUserIsAnonymous()) {
+            $this->addDefaultSubcategory($subcategories);
+        } else {
+            $dashboards = API::getInstance()->getDashboards();
+
+            if (empty($dashboards)) {
+                $this->addDefaultSubcategory($subcategories);
+            } else {
+                $order = 0;
+                foreach ($dashboards as $dashboard) {
+                    $subcategory = new Subcategory();
+                    $subcategory->setName($dashboard['name']);
+                    $subcategory->setCategoryId('Dashboard_Dashboard');
+                    $subcategory->setId($dashboard['id']);
+                    $subcategory->setOrder($order++);
+                    $subcategories[] = $subcategory;
+                }
+            }
+        }
+    }
+
+    private function addDefaultSubcategory(&$subcategories)
+    {
+        $subcategory = new Subcategory();
+        $subcategory->setName('Dashboard_Dashboard');
+        $subcategory->setCategoryId('Dashboard_Dashboard');
+        $subcategory->setId('1');
+        $subcategory->setOrder(1);
+        $subcategories[] = $subcategory;
+    }
+
     /**
      * Returns the layout in the DB for the given user, or false if the layout has not been set yet.
      * Parameters must be checked BEFORE this function call
@@ -63,32 +134,29 @@ class Dashboard extends \Piwik\Plugin
 
         if (empty($defaultLayout)) {
             $advertisingWidget = '';
-
             $advertising = StaticContainer::get('Piwik\ProfessionalServices\Advertising');
             if ($advertising->areAdsForProfessionalServicesEnabled() && Plugin\Manager::getInstance()->isPluginActivated('ProfessionalServices')) {
                 $advertisingWidget = '{"uniqueId":"widgetProfessionalServicespromoServices","parameters":{"module":"ProfessionalServices","action":"promoServices"}},';
             }
-
             if (Piwik::hasUserSuperUserAccess()) {
                 $piwikPromoWidget = '{"uniqueId":"widgetCoreHomegetDonateForm","parameters":{"module":"CoreHome","action":"getDonateForm"}}';
             } else {
                 $piwikPromoWidget = '{"uniqueId":"widgetCoreHomegetPromoVideo","parameters":{"module":"CoreHome","action":"getPromoVideo"}}';
             }
-
             $defaultLayout = '[
                 [
                     {"uniqueId":"widgetLivewidget","parameters":{"module":"Live","action":"widget"}},
                     ' . $piwikPromoWidget . '
                 ],
                 [
-                    {"uniqueId":"widgetVisitsSummarygetEvolutionGraphcolumnsArray","parameters":{"module":"VisitsSummary","action":"getEvolutionGraph","columns":"nb_visits"}},
+                    {"uniqueId":"widgetVisitsSummarygetEvolutionGraphforceView1viewDataTablegraphEvolution","parameters":{"forceView":"1","viewDataTable":"graphEvolution","module":"VisitsSummary","action":"getEvolutionGraph"}},
                     ' . $advertisingWidget . '
-                    {"uniqueId":"widgetVisitsSummarygetSparklines","parameters":{"module":"VisitsSummary","action":"getSparklines"}}
+                    {"uniqueId":"widgetVisitsSummarygetforceView1viewDataTablesparklines","parameters":{"forceView":"1","viewDataTable":"sparklines","module":"VisitsSummary","action":"get"}}
                 ],
                 [
                     {"uniqueId":"widgetUserCountryMapvisitorMap","parameters":{"module":"UserCountryMap","action":"visitorMap"}},
                     {"uniqueId":"widgetReferrersgetReferrerType","parameters":{"module":"Referrers","action":"getReferrerType"}},
-                    {"uniqueId":"widgetExampleRssWidgetrssPiwik","parameters":{"module":"ExampleRssWidget","action":"rssPiwik"}}
+                    {"uniqueId":"widgetRssWidgetrssPiwik","parameters":{"module":"RssWidget","action":"rssPiwik"}}
                 ]
             ]';
         }
@@ -165,24 +233,6 @@ class Dashboard extends \Piwik\Plugin
             );
         }
 
-        foreach ($layoutObject->columns as &$row) {
-            if (!is_array($row)) {
-                $row = array();
-                continue;
-            }
-
-            foreach ($row as $widgetId => $widget) {
-                if (isset($widget->parameters->module)) {
-                    $controllerName = $widget->parameters->module;
-                    $controllerAction = $widget->parameters->action;
-                    if (!WidgetsList::isDefined($controllerName, $controllerAction)) {
-                        unset($row[$widgetId]);
-                    }
-                } else {
-                    unset($row[$widgetId]);
-                }
-            }
-        }
         $layout = $this->encodeLayout($layoutObject);
         return $layout;
     }
@@ -207,11 +257,13 @@ class Dashboard extends \Piwik\Plugin
 
     public function getJsFiles(&$jsFiles)
     {
+        $jsFiles[] = "plugins/Dashboard/angularjs/common/services/dashboards-model.js";
         $jsFiles[] = "plugins/Dashboard/javascripts/widgetMenu.js";
         $jsFiles[] = "libs/javascript/json2.js";
         $jsFiles[] = "plugins/Dashboard/javascripts/dashboardObject.js";
         $jsFiles[] = "plugins/Dashboard/javascripts/dashboardWidget.js";
         $jsFiles[] = "plugins/Dashboard/javascripts/dashboard.js";
+        $jsFiles[] = "plugins/Dashboard/angularjs/dashboard/dashboard.directive.js";
     }
 
     public function getStylesheetFiles(&$stylesheets)
