@@ -6,6 +6,8 @@
  */
 (function ($) {
 
+    var layoutColumnSelector = '#dashboardWidgetsArea > .col';
+
     /**
      * Current dashboard column layout
      * @type {object}
@@ -57,9 +59,6 @@
 
             if (options.layout) {
                 generateLayout(options.layout);
-                buildMenu();
-            } else {
-                methods.loadDashboard.apply(this, [dashboardId]);
             }
 
             return this;
@@ -73,27 +72,33 @@
         destroy: function () {
             $(dashboardElement).remove();
             dashboardElement = null;
-            var widgets = $('[widgetId]');
-            for (var i = 0; i < widgets.length; i++) {
-                $(widgets[i]).dashboardWidget('destroy');
-            }
+            destroyWidgets();
         },
 
+        destroyWidgets: destroyWidgets,
+
         /**
          * Load dashboard with the given id
          *
          * @param {int} dashboardIdToLoad
          */
-        loadDashboard: function (dashboardIdToLoad) {
+        loadDashboard: function (dashboardIdToLoad, forceReload) {
+
             $(dashboardElement).empty();
             dashboardName = '';
             dashboardLayout = null;
             dashboardId = dashboardIdToLoad;
-            piwikHelper.showAjaxLoading();
-            broadcast.updateHashOnly = true;
-            broadcast.propagateAjax('?idDashboard=' + dashboardIdToLoad);
-            fetchLayout(generateLayout);
-            buildMenu();
+
+            if (!forceReload && piwikHelper.isAngularRenderingThePage()) {
+                angular.element(document).injector().invoke(function ($location) {
+                    $location.search('subcategory', '' + dashboardIdToLoad);
+                });
+            } else {
+                var element = $('[piwik-dashboard]');
+                var scope = angular.element(element).scope();
+                scope.fetchDashboard(dashboardIdToLoad);
+            }
+
             return this;
         },
 
@@ -169,9 +174,10 @@
                 action: 'resetLayout',
                 idDashboard: dashboardId
             }, 'get');
+            ajaxRequest.withTokenInUrl();
             ajaxRequest.setCallback(
                 function () {
-                    methods.loadDashboard.apply(this, [dashboardId])
+                    methods.loadDashboard.apply(this, [dashboardId, true])
                 }
             );
             ajaxRequest.setLoadingElement();
@@ -179,11 +185,31 @@
             ajaxRequest.send(true);
         },
 
+        rebuildMenu: rebuildMenu,
         /**
          * Removes the current dashboard
          */
         removeDashboard: function () {
-            removeDashboard();
+            if (dashboardId == 1) {
+                return; // dashboard with id 1 should never be deleted, as it is the default
+            }
+
+            var ajaxRequest = new ajaxHelper();
+            ajaxRequest.setLoadingElement();
+            ajaxRequest.addParams({
+                module: 'Dashboard',
+                action: 'removeDashboard',
+                idDashboard: dashboardId
+            }, 'get');
+            ajaxRequest.setCallback(
+                function () {
+                    methods.loadDashboard.apply(this, [1]);
+                    rebuildMenu();
+                }
+            );
+            ajaxRequest.withTokenInUrl();
+            ajaxRequest.setFormat('html');
+            ajaxRequest.send(true);
         },
 
         /**
@@ -201,6 +227,47 @@
         }
     };
 
+    function destroyWidgets()
+    {
+        var widgets = $('[widgetId]');
+        for (var i = 0; i < widgets.length; i++) {
+            $(widgets[i]).dashboardWidget('destroy');
+        }
+    }
+
+    function removeNonExistingWidgets(availableWidgets, layout)
+    {
+        var existingModuleAction = {};
+        $.each(availableWidgets, function (category, widgets) {
+            $.each(widgets, function (index, widget) {
+                existingModuleAction[widget.module + '.' + widget.action] = true;
+            });
+        });
+
+        var columns = [];
+        $.each(layout.columns, function (i, column) {
+            var widgets = [];
+
+            $.each(column, function (j, widget) {
+                if (!widget.parameters || !widget.parameters.module) {
+                    return;
+                }
+
+                var method = widget.parameters.module + '.' + widget.parameters.action
+                if (existingModuleAction[method]) {
+                    widgets.push(widget);
+                }
+
+            });
+
+            columns[i] = widgets;
+        });
+
+        layout.columns = columns;
+
+        return layout;
+    }
+
     /**
      * Generates the dashboard out of the given layout
      *
@@ -209,46 +276,33 @@
     function generateLayout(layout) {
 
         dashboardLayout = parseLayout(layout);
-        piwikHelper.hideAjaxLoading();
-        adjustDashboardColumns(dashboardLayout.config.layout);
 
-        var dashboardContainsWidgets = false;
-        for (var column = 0; column < dashboardLayout.columns.length; column++) {
-            for (var i in dashboardLayout.columns[column]) {
-                if (typeof dashboardLayout.columns[column][i] != 'object') {
-                    // Fix IE8 bug: the "i in" loop contains i="indexOf", which would yield type function.
-                    // If we would continue with i="indexOf", an invalid widget would be created.
-                    continue;
+        widgetsHelper.getAvailableWidgets(function (availableWidgets) {
+            dashboardLayout = removeNonExistingWidgets(availableWidgets, dashboardLayout);
+
+            piwikHelper.hideAjaxLoading();
+            adjustDashboardColumns(dashboardLayout.config.layout);
+
+            var dashboardContainsWidgets = false;
+            for (var column = 0; column < dashboardLayout.columns.length; column++) {
+                for (var i in dashboardLayout.columns[column]) {
+                    if (typeof dashboardLayout.columns[column][i] != 'object') {
+                        // Fix IE8 bug: the "i in" loop contains i="indexOf", which would yield type function.
+                        // If we would continue with i="indexOf", an invalid widget would be created.
+                        continue;
+                    }
+                    var widget = dashboardLayout.columns[column][i];
+                    dashboardContainsWidgets = true;
+                    addWidgetTemplate(widget.uniqueId, column + 1, widget.parameters, false, widget.isHidden)
                 }
-                var widget = dashboardLayout.columns[column][i];
-                dashboardContainsWidgets = true;
-                addWidgetTemplate(widget.uniqueId, column + 1, widget.parameters, false, widget.isHidden)
             }
-        }
 
-        if (!dashboardContainsWidgets) {
-            $(dashboardElement).trigger('dashboardempty');
-        }
+            if (!dashboardContainsWidgets) {
+                $(dashboardElement).trigger('dashboardempty');
+            }
 
-        makeWidgetsSortable();
-    }
-
-    /**
-     * Fetches the layout for the currently set dashboard id
-     * and passes the response to given callback function
-     *
-     * @param {function} callback
-     */
-    function fetchLayout(callback) {
-        globalAjaxQueue.abort();
-        var ajaxRequest = new ajaxHelper();
-        ajaxRequest.addParams({
-            module: 'Dashboard',
-            action: 'getDashboardLayout',
-            idDashboard: dashboardId
-        }, 'get');
-        ajaxRequest.setCallback(callback);
-        ajaxRequest.send(false);
+            makeWidgetsSortable();
+        });
     }
 
     /**
@@ -262,7 +316,7 @@
         var columnWidth = layout.split('-');
         var columnCount = columnWidth.length;
 
-        var currentCount = $('.col', dashboardElement).length;
+        var currentCount = $('> .col', dashboardElement).length;
 
         if (currentCount < columnCount) {
             $('.menuClear', dashboardElement).remove();
@@ -279,8 +333,8 @@
                     dashboardLayout.columns.pop();
                 }
                 // move widgets to other columns depending on columns height
-                $('[widgetId]', $('.col:last')).each(function (id, elem) {
-                    var cols = $('.col').slice(0, columnCount);
+                $('[widgetId]', $(layoutColumnSelector + ':last')).each(function (id, elem) {
+                    var cols = $(layoutColumnSelector).slice(0, columnCount);
                     var smallestColumn = $(cols[0]);
                     var smallestColumnHeight = null;
                     cols.each(function (colId, col) {
@@ -293,52 +347,56 @@
                     $(elem).appendTo(smallestColumn);
                 });
 
-                $('.col:last').remove();
+                $(layoutColumnSelector + ':last').remove();
             }
         }
 
+        var $dashboardElement = $(' > .col', dashboardElement);
+
+        if (!$dashboardElement.size()) {
+            return;
+        }
+
         switch (layout) {
             case '100':
-                $('.col', dashboardElement).removeClass()
-                    .addClass('col col-sm-12');
+                $dashboardElement.removeClass().addClass('col s12');
                 break;
             case '50-50':
-                $('.col', dashboardElement).removeClass()
-                    .addClass('col col-sm-6');
+                $dashboardElement.removeClass().addClass('col s12 m6');
                 break;
             case '67-33':
-                $('.col', dashboardElement)[0].className = 'col col-sm-8';
-                $('.col', dashboardElement)[1].className = 'col col-sm-4';
+                $dashboardElement[0].className = 'col s12 m8';
+                $dashboardElement[1].className = 'col s12 m4';
                 break;
             case '33-67':
-                $('.col', dashboardElement)[0].className = 'col col-sm-4';
-                $('.col', dashboardElement)[1].className = 'col col-sm-8';
+                $dashboardElement[0].className = 'col s12 m4';
+                $dashboardElement[1].className = 'col s12 m8';
                 break;
             case '33-33-33':
-                $('.col', dashboardElement)[0].className = 'col col-sm-4';
-                $('.col', dashboardElement)[1].className = 'col col-sm-4';
-                $('.col', dashboardElement)[2].className = 'col col-sm-4';
+                $dashboardElement[0].className = 'col s12 m4';
+                $dashboardElement[1].className = 'col s12 m4';
+                $dashboardElement[2].className = 'col s12 m4';
                 break;
             case '40-30-30':
-                $('.col', dashboardElement)[0].className = 'col col-sm-6';
-                $('.col', dashboardElement)[1].className = 'col col-sm-3';
-                $('.col', dashboardElement)[2].className = 'col col-sm-3';
+                $dashboardElement[0].className = 'col s12 m6';
+                $dashboardElement[1].className = 'col s12 m3';
+                $dashboardElement[2].className = 'col s12 m3';
                 break;
             case '30-40-30':
-                $('.col', dashboardElement)[0].className = 'col col-sm-3';
-                $('.col', dashboardElement)[1].className = 'col col-sm-6';
-                $('.col', dashboardElement)[2].className = 'col col-sm-3';
+                $dashboardElement[0].className = 'col s12 m3';
+                $dashboardElement[1].className = 'col s12 m6';
+                $dashboardElement[2].className = 'col s12 m3';
                 break;
             case '30-30-40':
-                $('.col', dashboardElement)[0].className = 'col col-sm-3';
-                $('.col', dashboardElement)[1].className = 'col col-sm-3';
-                $('.col', dashboardElement)[2].className = 'col col-sm-6';
+                $dashboardElement[0].className = 'col s12 m3';
+                $dashboardElement[1].className = 'col s12 m3';
+                $dashboardElement[2].className = 'col s12 m6';
                 break;
             case '25-25-25-25':
-                $('.col', dashboardElement)[0].className = 'col col-sm-3';
-                $('.col', dashboardElement)[1].className = 'col col-sm-3';
-                $('.col', dashboardElement)[2].className = 'col col-sm-3';
-                $('.col', dashboardElement)[3].className = 'col col-sm-3';
+                $dashboardElement[0].className = 'col s12 m3';
+                $dashboardElement[1].className = 'col s12 m3';
+                $dashboardElement[2].className = 'col s12 m3';
+                $dashboardElement[3].className = 'col s12 m3';
                 break;
         }
 
@@ -388,7 +446,7 @@
      * @param {String} uniqueId
      */
     function reloadWidget(uniqueId) {
-        $('[widgetId=' + uniqueId + ']', dashboardElement).dashboardWidget('reload', false, true);
+        $('[widgetId="' + uniqueId + '"]', dashboardElement).dashboardWidget('reload', false, true);
     }
 
     /**
@@ -405,19 +463,19 @@
         }
 
         // do not try to add widget if given column number is to high
-        if (columnNumber > $('.col', dashboardElement).length) {
+        if (columnNumber > $('> .col', dashboardElement).length) {
             return;
         }
 
         var widgetContent = '<div class="sortable" widgetId="' + uniqueId + '"></div>';
 
         if (addWidgetOnTop) {
-            $('.col:nth-child(' + columnNumber + ')', dashboardElement).prepend(widgetContent);
+            $('> .col:nth-child(' + columnNumber + ')', dashboardElement).prepend(widgetContent);
         } else {
-            $('.col:nth-child(' + columnNumber + ')', dashboardElement).append(widgetContent);
+            $('> .col:nth-child(' + columnNumber + ')', dashboardElement).append(widgetContent);
         }
 
-        $('[widgetId=' + uniqueId + ']', dashboardElement).dashboardWidget({
+        $('[widgetId="' + uniqueId + '"]', dashboardElement).dashboardWidget({
             uniqueId: uniqueId,
             widgetParameters: widgetParameters,
             onChange: function () {
@@ -448,9 +506,9 @@
         }
 
         //launch 'sortable' property on every dashboard widgets
-        $( "div.col:data('ui-sortable')", dashboardElement ).sortable('destroy');
+        $( layoutColumnSelector + ":data('ui-sortable')", dashboardElement ).sortable('destroy');
 
-        $('div.col', dashboardElement)
+        $('> .col', dashboardElement)
                     .sortable({
                         items: 'div.sortable',
                         opacity: 0.6,
@@ -461,14 +519,26 @@
                         helper: 'clone',
                         start: onStart,
                         stop: onStop,
-                        connectWith: 'div.col'
+                        connectWith: layoutColumnSelector
                     });
     }
 
     /**
      * Handle clicks for menu items for choosing between available dashboards
      */
-    function buildMenu() {
+    function rebuildMenu() {
+
+        if (piwikHelper.isAngularRenderingThePage()) {
+            // dashboard in reporting page (regular Piwik UI)
+            angular.element(document).injector().invoke(function (reportingMenuModel) {
+                reportingMenuModel.reloadMenuItems();
+            });
+            return;
+        }
+
+        var _self = this;
+
+        // widgetized
         var success = function (dashboards) {
             var dashboardMenuList = $('#Dashboard_embeddedIndex_1').closest('ul');
             var dashboardMenuListItems = dashboardMenuList.find('>li');
@@ -487,13 +557,13 @@
                 var items = [];
                 for (var i = 0; i < dashboards.length; i++) {
                     var $link = $('<a/>').attr('data-iddashboard', dashboards[i].iddashboard).text(dashboards[i].name).addClass('item');
-                    var $li = $('<li/>').attr('id', 'Dashboard_embeddedIndex_' + dashboards[i].iddashboard)
-                                        .attr('role', 'menuitem').append($link);
+                    var $li = $('<li/>').attr('id', 'Dashboard_embeddedIndex_' + dashboards[i].iddashboard).addClass('dashboardMenuItem').attr('role', 'menuitem').append($link);
+
                     items.push($li);
 
                     if (dashboards[i].iddashboard == dashboardId) {
                         dashboardName = dashboards[i].name;
-                        $li.addClass('sfActive');
+                        $li.addClass('active');
                     }
                 }
                 dashboardMenuList.prepend(items);
@@ -504,23 +574,23 @@
 
                 var idDashboard = $(this).attr('data-iddashboard');
 
-                $('li', dashboardMenuList).removeClass('sfActive');
-                if ($(dashboardElement).length) {
-                    $(dashboardElement).dashboard('loadDashboard', idDashboard);
-                } else {
-                    broadcast.propagateAjax('module=Dashboard&action=embeddedIndex&idDashboard=' + idDashboard);
-                }
-                $(this).closest('li').addClass('sfActive');
+                $('#Dashboard ul li').removeClass('active');
+
+                methods.loadDashboard.apply(_self, [idDashboard]);
+
+                $(this).closest('li').addClass('active');
             });
         };
 
         var ajaxRequest = new ajaxHelper();
         ajaxRequest.addParams({
             module: 'Dashboard',
-            action: 'getAllDashboards'
+            action: 'getAllDashboards',
+            filter_limit: '-1'
         }, 'get');
+        ajaxRequest.withTokenInUrl();
         ajaxRequest.setCallback(success);
-        ajaxRequest.send(false);
+        ajaxRequest.send();
     }
 
     /**
@@ -531,7 +601,8 @@
         var columns = [];
 
         var columnNumber = 0;
-        $('.col').each(function () {
+
+        $(layoutColumnSelector).each(function () {
             columns[columnNumber] = [];
             var items = $('[widgetId]', this);
             for (var j = 0; j < items.size(); j++) {
@@ -567,39 +638,17 @@
                 function () {
                     if (dashboardChanged) {
                         dashboardChanged = false;
-                        buildMenu();
+                        rebuildMenu();
                     }
                 }
             );
+
+            ajaxRequest.withTokenInUrl();
             ajaxRequest.setFormat('html');
             ajaxRequest.send(false);
         }
     }
 
-    /**
-     * Removes the current dashboard
-     */
-    function removeDashboard() {
-        if (dashboardId == 1) {
-            return; // dashboard with id 1 should never be deleted, as it is the default
-        }
-
-        var ajaxRequest = new ajaxHelper();
-        ajaxRequest.setLoadingElement();
-        ajaxRequest.addParams({
-            module: 'Dashboard',
-            action: 'removeDashboard',
-            idDashboard: dashboardId
-        }, 'get');
-        ajaxRequest.setCallback(
-            function () {
-                methods.loadDashboard.apply(this, [1]);
-            }
-        );
-        ajaxRequest.setFormat('html');
-        ajaxRequest.send(true);
-    }
-
     /**
      * Make plugin methods available
      */
