@@ -25,7 +25,6 @@ class DevicePlugins extends \Piwik\Plugin
         return array(
             'Metrics.getDefaultMetricTranslations' => 'addMetricTranslations',
             'Live.getAllVisitorDetails'            => 'extendVisitorDetails',
-            'Request.getRenamedModuleAndAction' => 'renameUserSettingsModuleAndAction',
         );
     }
 
@@ -45,11 +44,4 @@ class DevicePlugins extends \Piwik\Plugin
 
         $translations = array_merge($translations, $metrics);
     }
-
-    public function renameUserSettingsModuleAndAction(&$module, &$action)
-    {
-        if ($module == 'UserSettings' && $action == 'getPlugin') {
-            $module = 'DevicePlugins';
-        }
-    }
 }
