@@ -18,14 +18,14 @@ use Piwik\Tracker\Action;
 class Os extends Base
 {
     protected $columnName = 'config_os';
-    protected $columnType = 'CHAR(3) NOT NULL';
+    protected $columnType = 'CHAR(3) NULL';
 
     protected function configureSegments()
     {
         $segment = new Segment();
         $segment->setSegment('operatingSystemCode');
         $segment->setName('DevicesDetection_ColumnOperatingSystem');
-        $segment->setAcceptedValues('WXP, WI7, MAC, LIN, AND, IPD, etc.');
+        $segment->setAcceptedValues('WIN, MAC, LIN, AND, IPD, etc.');
         $this->addSegment($segment);
     }
 
