@@ -9,7 +9,6 @@
 namespace Piwik\Plugins\DevicesDetection;
 
 use Piwik\Menu\MenuAdmin;
-use Piwik\Menu\MenuReporting;
 use Piwik\Piwik;
 
 /**
@@ -20,14 +19,8 @@ class Menu extends \Piwik\Plugin\Menu
     {
         if (Piwik::isUserHasSomeAdminAccess()) {
             $menu->addDiagnosticItem('DevicesDetection_DeviceDetection',
-                                     $this->urlForAction('deviceDetection'),
+                                     $this->urlForAction('detection'),
                                      $order = 40);
         }
     }
-
-    public function configureReportingMenu(MenuReporting $menu)
-    {
-        $menu->addVisitorsItem('DevicesDetection_Devices', $this->urlForAction('devices'));
-        $menu->addVisitorsItem('DevicesDetection_Software', $this->urlForAction('software'));
-    }
 }
