@@ -20,8 +20,9 @@ class GetBrand extends Base
         $this->dimension     = new DeviceBrand();
         $this->name          = Piwik::translate('DevicesDetection_DeviceBrand');
         $this->documentation = ''; // TODO
-        $this->order = 1;
-        $this->widgetTitle  = 'DevicesDetection_DeviceBrand';
+        $this->order = 4;
+        $this->hasGoalMetrics = true;
+        $this->subcategoryId = 'DevicesDetection_Devices';
     }
 
     public function configureView(ViewDataTable $view)
