@@ -22,7 +22,8 @@ class GetType extends Base
         $this->name          = Piwik::translate('DevicesDetection_DeviceType');
         $this->documentation = ''; // TODO
         $this->order = 0;
-        $this->widgetTitle  = 'DevicesDetection_DeviceType';
+        $this->hasGoalMetrics = true;
+        $this->subcategoryId = 'DevicesDetection_Devices';
     }
 
     public function configureView(ViewDataTable $view)
