@@ -17,11 +17,11 @@ use DeviceDetector\Parser\Client\Browser AS BrowserParser;
 function getBrandLogo($label)
 {
     $label = preg_replace("/[^a-z0-9_-]+/i", "_", $label);
-    $path = dirname(__FILE__) . '/images/brand/' . $label . '.ico';
+    $path = dirname(__FILE__) . '/images/brand/' . $label . '.png';
     if (file_exists($path)) {
-        return 'plugins/DevicesDetection/images/brand/' . $label . '.ico';
+        return 'plugins/DevicesDetection/images/brand/' . $label . '.png';
     } else {
-        return 'plugins/DevicesDetection/images/brand/Unknown.ico';
+        return 'plugins/DevicesDetection/images/brand/Unknown.png';
     }
 }
 
@@ -72,7 +72,7 @@ function getBrowserName($label)
  *
  * First try to find a logo for the given short code
  * If none can be found try to find a logo for the browser family
- * Return unkown logo otherwise
+ * Return unknown logo otherwise
  *
  * @param string  $short  Shortcode or name of browser
  *
@@ -80,7 +80,7 @@ function getBrowserName($label)
  */
 function getBrowserLogo($short)
 {
-    $path = 'plugins/DevicesDetection/images/browsers/%s.gif';
+    $path = 'plugins/Morpheus/icons/dist/browsers/%s.png';
 
     // If name is given instead of short code, try to find matching shortcode
     if (strlen($short) > 2) {
@@ -160,17 +160,17 @@ function getDeviceTypeLogo($label)
     $label = strtolower($label);
 
     $deviceTypeLogos = Array(
-        "desktop"       => "normal.gif",
+        "desktop"       => "normal.png",
         "smartphone"    => "smartphone.png",
         "tablet"        => "tablet.png",
         "tv"            => "tv.png",
-        "feature phone" => "mobile.gif",
-        "console"       => "console.gif",
+        "feature phone" => "mobile.png",
+        "console"       => "console.png",
         "car browser"   => "carbrowser.png",
         "camera"        => "camera.png");
 
     if (!array_key_exists($label, $deviceTypeLogos)) {
-        $label = 'unknown.gif';
+        $label = 'unknown.png';
     } else {
         $label = $deviceTypeLogos[$label];
     }
@@ -282,7 +282,7 @@ function _mapLegacyOsShortCodes($shortCode)
  */
 function getOsLogo($short)
 {
-    $path = 'plugins/DevicesDetection/images/os/%s.gif';
+    $path = 'plugins/Morpheus/icons/dist/os/%s.png';
 
     $short = _mapLegacyOsShortCodes($short);
 
