@@ -73,18 +73,6 @@ class ActionEvent extends Action
         return array('idaction_url' => $actionUrl);
     }
 
-    // Do not track this Event URL as Entry/Exit Page URL (leave the existing entry/exit)
-    public function getIdActionUrlForEntryAndExitIds()
-    {
-        return false;
-    }
-
-    // Do not track this Event Name as Entry/Exit Page Title (leave the existing entry/exit)
-    public function getIdActionNameForEntryAndExitIds()
-    {
-        return false;
-    }
-
     public function writeDebugInfo()
     {
         $write = parent::writeDebugInfo();
