@@ -13,6 +13,7 @@ use Piwik\DataTable;
 use Piwik\Piwik;
 use Piwik\Plugin\Report;
 use Piwik\Plugin\ViewDataTable;
+use Piwik\Plugin\ReportsProvider;
 use Piwik\Plugins\CoreVisualizations\Visualizations\HtmlTable\AllColumns;
 
 class Events extends \Piwik\Plugin
@@ -143,7 +144,8 @@ class Events extends \Piwik\Plugin
         $secondaryDimension = $this->getSecondaryDimensionFromRequest();
         $view->config->subtable_controller_action = API::getInstance()->getActionToLoadSubtables($apiMethod, $secondaryDimension);
 
-        if (Common::getRequestVar('pivotBy', false) === false) {
+        $pivotBy = Common::getRequestVar('pivotBy', false);
+        if (empty($pivotBy)) {
             $view->config->columns_to_display = array('label', 'nb_events', 'sum_event_value');
         }
 
@@ -178,7 +180,7 @@ class Events extends \Piwik\Plugin
         $this->addRelatedReports($view, $secondaryDimension);
         $this->addTooltipEventValue($view);
 
-        $subtableReport = Report::factory('Events', $view->config->subtable_controller_action);
+        $subtableReport = ReportsProvider::factory('Events', $view->config->subtable_controller_action);
         $view->config->pivot_by_dimension = $subtableReport->getDimension()->getId();
         $view->config->pivot_by_column = 'nb_events';
     }
