@@ -18,7 +18,7 @@ abstract class Base extends \Piwik\Plugin\Report
 
     protected function init()
     {
-        $this->category = 'Goals_Goals';
+        $this->categoryId = 'Goals_Goals';
     }
 
     protected function addReportMetadataForEachGoal(&$availableReports, $infos, $goalNameFormatter)
@@ -41,14 +41,12 @@ abstract class Base extends \Piwik\Plugin\Report
 
     protected function getIdSiteFromInfos($infos)
     {
-        $idSites = $infos['idSites'];
+        $idSite = $infos['idSite'];
 
-        if (count($idSites) != 1) {
+        if (empty($idSite)) {
             return null;
         }
 
-        $idSite = reset($idSites);
-
         return $idSite;
     }
 
