@@ -22,7 +22,7 @@ use Piwik\View;
 class Goals extends HtmlTable
 {
     const ID = 'tableGoals';
-    const FOOTER_ICON       = 'plugins/Morpheus/images/goal.png';
+    const FOOTER_ICON       = 'icon-goal';
     const FOOTER_ICON_TITLE = 'General_DisplayTableWithGoalMetrics';
 
     public function beforeLoadDataTable()
