@@ -10,7 +10,6 @@
 namespace Piwik\Plugins\Insights\Visualizations;
 
 use Piwik\Common;
-use Piwik\DataTable;
 use Piwik\Plugin\ViewDataTable;
 use Piwik\Plugin\Visualization;
 use Piwik\Plugins\Insights\API;
@@ -25,7 +24,7 @@ class Insight extends Visualization
     const ID = 'insightsVisualization';
     const TEMPLATE_FILE     = '@Insights/insightVisualization.twig';
     const FOOTER_ICON_TITLE = 'Insights';
-    const FOOTER_ICON       = 'plugins/Insights/images/idea.png';
+    const FOOTER_ICON       = 'icon-insights';
 
     public function beforeLoadDataTable()
     {
@@ -40,6 +39,10 @@ class Insight extends Visualization
         $report = $this->requestConfig->apiMethodToRequestDataTable;
         $report = str_replace('.', '_', $report);
 
+        if (!empty($this->requestConfig->request_parameters_to_modify['reportUniqueId'])) {
+            $report = $this->requestConfig->request_parameters_to_modify['reportUniqueId'];
+        }
+
         $this->requestConfig->apiMethodToRequestDataTable = 'Insights.getInsights';
 
         $this->requestConfig->request_parameters_to_modify = array(
@@ -49,6 +52,8 @@ class Insight extends Visualization
             'comparedToXPeriods' => $this->requestConfig->compared_to_x_periods_ago,
             'orderBy'  => $this->requestConfig->order_by,
             'filterBy' => $this->requestConfig->filter_by,
+            'pivotBy' => false,
+            'pivotByColumn' => false,
             'limitIncreaser' => $this->getLimitIncrease(),
             'limitDecreaser' => $this->getLimitDecrease(),
         );
@@ -90,6 +95,7 @@ class Insight extends Visualization
     {
         $this->config->datatable_js_type = 'InsightsDataTable';
         $this->config->show_limit_control = true;
+        $this->config->show_pivot_by_subtable = false;
         $this->config->show_pagination_control = false;
         $this->config->show_offset_information = false;
         $this->config->show_search = false;
