@@ -52,7 +52,8 @@ class Model
 					log_link_visit_action.server_time as serverTimePretty,
 					log_link_visit_action.time_spent_ref_action as timeSpentRef,
 					log_link_visit_action.idlink_va AS pageId,
-					log_link_visit_action.custom_float
+					log_link_visit_action.custom_float,
+					log_link_visit_action.interaction_position
 					" . $sqlCustomVariables . ",
 					log_action_event_category.name AS eventCategory,
 					log_action_event_action.name as eventAction
@@ -116,8 +117,8 @@ class Model
     {
         $sql = "SELECT
 						case idgoal when " . GoalManager::IDGOAL_CART
-                            . " then '" . Piwik::LABEL_ID_GOAL_IS_ECOMMERCE_CART
-                            . "' else '" . Piwik::LABEL_ID_GOAL_IS_ECOMMERCE_ORDER . "' end as type,
+            . " then '" . Piwik::LABEL_ID_GOAL_IS_ECOMMERCE_CART
+            . "' else '" . Piwik::LABEL_ID_GOAL_IS_ECOMMERCE_ORDER . "' end as type,
 						idorder as orderId,
 						" . LogAggregator::getSqlRevenue('revenue') . " as revenue,
 						" . LogAggregator::getSqlRevenue('revenue_subtotal') . " as revenueSubTotal,
@@ -136,6 +137,29 @@ class Model
         return $ecommerceDetails;
     }
 
+    /**
+     * @param $idSite
+     * @param $idVisit
+     * @return array
+     * @throws \Exception
+     */
+    public function queryEcommerceConversionsVisitorLifeTimeMetricsForVisitor($idSite, $idVisitor)
+    {
+        $sql = $this->getSqlEcommerceConversionsLifeTimeMetricsForIdGoal(GoalManager::IDGOAL_ORDER);
+        $ecommerceOrders = Db::fetchRow($sql, array($idSite, @Common::hex2bin($idVisitor)));
+
+        $sql = $this->getSqlEcommerceConversionsLifeTimeMetricsForIdGoal(GoalManager::IDGOAL_CART);
+        $abandonedCarts = Db::fetchRow($sql, array($idSite, @Common::hex2bin($idVisitor)));
+
+        return array(
+            'totalEcommerceRevenue'      => $ecommerceOrders['lifeTimeRevenue'],
+            'totalEcommerceConversions'  => $ecommerceOrders['lifeTimeConversions'],
+            'totalEcommerceItems'        => $ecommerceOrders['lifeTimeEcommerceItems'],
+            'totalAbandonedCartsRevenue' => $abandonedCarts['lifeTimeRevenue'],
+            'totalAbandonedCarts'        => $abandonedCarts['lifeTimeConversions'],
+            'totalAbandonedCartsItems'   => $abandonedCarts['lifeTimeEcommerceItems']
+        );
+    }
 
     /**
      * @param $idVisit
@@ -402,23 +426,34 @@ class Model
 
         $orderBy = '';
         if (count($bindIdSites) <= 1) {
-            $orderBy = 'idsite, ';
+            $orderBy = 'idsite ' . $filterSortOrder . ', ';
         }
 
         $orderBy .= "visit_last_action_time " . $filterSortOrder;
         $orderByParent = "sub.visit_last_action_time " . $filterSortOrder;
 
-        $subQuery = $segment->getSelectQuery($select, $from, $where, $whereBind, $orderBy, $groupBy, $limit, $offset);
+        // this $innerLimit is a workaround (see https://github.com/piwik/piwik/issues/9200#issuecomment-183641293)
+        $innerLimit = $limit;
+        if (!$segment->isEmpty()) {
+            $innerLimit = $limit * 10;
+        }
 
-        $bind = $subQuery['bind'];
-        // Group by idvisit so that a visitor converting 2 goals only appears once
+        $innerQuery = $segment->getSelectQuery($select, $from, $where, $whereBind, $orderBy, $groupBy, $innerLimit, $offset);
+
+        $bind = $innerQuery['bind'];
+        // Group by idvisit so that a given visit appears only once, useful when for example:
+        // 1) when a visitor converts 2 goals
+        // 2) when an Action Segment is used, the inner query will return one row per action, but we want one row per visit
         $sql = "
 			SELECT sub.* FROM (
-				" . $subQuery['sql'] . "
+				" . $innerQuery['sql'] . "
 			) AS sub
 			GROUP BY sub.idvisit
 			ORDER BY $orderByParent
 		";
+        if($limit) {
+            $sql .= sprintf("LIMIT %d \n", $limit);
+        }
         return array($sql, $bind);
     }
 
@@ -503,4 +538,25 @@ class Model
         }
         return array($whereBind, $where);
     }
+
+    /**
+     * @param $ecommerceIdGoal
+     * @return string
+     */
+    private function getSqlEcommerceConversionsLifeTimeMetricsForIdGoal($ecommerceIdGoal)
+    {
+        $sql = "SELECT
+                    COALESCE(SUM(" . LogAggregator::getSqlRevenue('revenue') . "), 0) as lifeTimeRevenue,
+                    COUNT(*) as lifeTimeConversions,
+                    COALESCE(SUM(" . LogAggregator::getSqlRevenue('items') . "), 0)  as lifeTimeEcommerceItems
+					FROM  " . Common::prefixTable('log_visit') . " AS log_visit
+					    LEFT JOIN " . Common::prefixTable('log_conversion') . " AS log_conversion
+					    ON log_visit.idvisit = log_conversion.idvisit
+					WHERE
+					        log_visit.idsite = ?
+					    AND log_visit.idvisitor = ?
+						AND log_conversion.idgoal = " . $ecommerceIdGoal . "
+        ";
+        return $sql;
+    }
 } 
