@@ -275,7 +275,7 @@ $(function() {
 
             scheduleAnotherRequest();
         });
-        ajaxRequest.send(true);
+        ajaxRequest.send();
     };
 
     var exports = require("piwik/Live");
