@@ -99,6 +99,8 @@ function ajaxHelper() {
      */
     this.errorCallback =  this.defaultErrorCallback;
 
+    this.withToken = false;
+
     /**
      * Callback function to be executed on complete (after error or success)
      */
@@ -173,6 +175,10 @@ function ajaxHelper() {
         }
     };
 
+    this.withTokenInUrl = function () {
+        this.withToken = true;
+    };
+
     /**
      * Sets the base URL to use in the AJAX request.
      *
@@ -470,11 +476,24 @@ function ajaxHelper() {
         return $.ajax(ajaxCall);
     };
 
+    this._isRequestToApiMethod = function () {
+        return (this.getParams && this.getParams['module'] === 'API' && this.getParams['method']) ||
+               (this.postParams && this.postParams['module'] === 'API' && this.postParams['method']);
+    };
+
+    this._isWidgetizedRequest = function () {
+        return (broadcast.getValueFromUrl('module') == 'Widgetize');
+    };
+
     this._getDefaultPostParams = function () {
-        return {
-            token_auth: piwik.token_auth
-        };
-    }
+        if (this.withToken || this._isRequestToApiMethod() || this._isWidgetizedRequest()) {
+            return {
+                token_auth: piwik.token_auth
+            };
+        }
+
+        return {};
+    };
 
     /**
      * Mixin the default parameters to send as POST
