@@ -285,7 +285,7 @@ class API extends \Piwik\Plugin\API
         // ResponseBuilder throws 'Call to a member function getColumns() on a non-object'
         if ($multipleWebsitesRequested
             // We don't delete the 0 visits row, if "Enhanced" mode is on.
-            && !$enhanced
+            && !$enhanced && (empty($showColumns) || in_array(self::NB_VISITS_METRIC, $showColumns))
         ) {
             $dataTable->filter(
                 'ColumnCallbackDeleteRow',
@@ -440,7 +440,11 @@ class API extends \Piwik\Plugin\API
                 $totals[$label] = 0;
             }
 
-            foreach ($dataTable->getRows() as $row) {
+            $rows = $dataTable->getRows();
+
+            $rows = $this->filterRowsForTotalsCalculation($rows);
+
+            foreach ($rows as $row) {
                 foreach ($apiMetrics as $totalMetadataName => $recordName) {
                     $totals[$totalMetadataName] += $row->getColumn($recordName);
                 }
@@ -462,7 +466,10 @@ class API extends \Piwik\Plugin\API
             $total  = 0;
             $metric = 'nb_visits';
 
-            foreach ($pastTable->getRows() as $row) {
+            $rows = $pastTable->getRows();
+            $rows = $this->filterRowsForTotalsCalculation($rows);
+
+            foreach ($rows as $row) {
                 $total += $row->getColumn($metric);
             }
 
@@ -470,6 +477,34 @@ class API extends \Piwik\Plugin\API
         }
     }
 
+    /**
+     * @param Row[] $rows
+     * @return mixed
+     */
+    private function filterRowsForTotalsCalculation($rows)
+    {
+        /**
+         * Triggered to filter / restrict which rows should be included in the MultiSites (All Websites Dashboard)
+         * totals calculation
+         *
+         * **Example**
+         *
+         *     public function filterMultiSitesRows(&$rows)
+         *     {
+         *         foreach ($rows as $index => $row) {
+         *             if ($row->getColumn('label') === 5) {
+         *                 unset($rows[$index]); // remove idSite 5 from totals
+         *             }
+         *         }
+         *     }
+         *
+         * @param Row[] &$rows An array containing rows, one row for each site. The label columns equals the idSite.
+         */
+        Piwik::postEvent('MultiSites.filterRowsForTotalsCalculation', array(&$rows));
+
+        return $rows;
+    }
+
     private static function getTotalMetadataName($name)
     {
         return 'total_' . $name;
