@@ -11,6 +11,7 @@ namespace Piwik\Plugins\Overlay;
 use Exception;
 use Piwik\Access;
 use Piwik\Config;
+use Piwik\Container\StaticContainer;
 use Piwik\DataTable;
 use Piwik\Piwik;
 use Piwik\Plugins\SitesManager\API as APISitesManager;
@@ -105,26 +106,26 @@ class API extends \Piwik\Plugin\API
     {
         /**
          * Triggered immediately before the user is authenticated.
-         * 
+         *
          * This event can be used by plugins that provide their own authentication mechanism
-         * to make that mechanism available. Subscribers should set the `'auth'` object in
-         * the {@link Piwik\Registry} to an object that implements the {@link Piwik\Auth} interface.
-         * 
+         * to make that mechanism available. Subscribers should set the `'Piwik\Auth'` object in
+         * the container to an object that implements the {@link Piwik\Auth} interface.
+         *
          * **Example**
-         * 
-         *     use Piwik\Registry;
-         * 
+         *
+         *     use Piwik\Container\StaticContainer;
+         *
          *     public function initAuthenticationObject($activateCookieAuth)
          *     {
-         *         Registry::set('auth', new LDAPAuth($activateCookieAuth));
+         *         StaticContainer::getContainer()->set('Piwik\Auth', new LDAPAuth($activateCookieAuth));
          *     }
-         * 
+         *
          * @param bool $activateCookieAuth Whether authentication based on `$_COOKIE` values should
          *                                        be allowed.
          */
         Piwik::postEvent('Request.initAuthenticationObject', array($activateCookieAuth = true));
 
-        $auth = \Piwik\Registry::get('auth');
+        $auth = StaticContainer::get('Piwik\Auth');
         $success = Access::getInstance()->reloadAccess($auth);
 
         if (!$success) {
