@@ -13,17 +13,26 @@ use Piwik\Piwik;
 use Piwik\Plugin\Report;
 use Piwik\Plugin\ViewDataTable;
 use Piwik\Plugins\Provider\Columns\Provider;
+use Piwik\Report\ReportWidgetFactory;
+use Piwik\Widget\WidgetsList;
 
 class GetProvider extends Report
 {
     protected function init()
     {
-        $this->category      = 'General_Visitors';
+        $this->categoryId      = 'General_Visitors';
         $this->dimension     = new Provider();
         $this->name          = Piwik::translate('Provider_ColumnProvider');
         $this->documentation = Piwik::translate('Provider_ProviderReportDocumentation', '<br />');
         $this->order = 50;
-        $this->widgetTitle  = 'Provider_WidgetProviders';
+
+        $this->subcategoryId = 'UserCountry_SubmenuLocations';
+    }
+
+    public function configureWidgets(WidgetsList $widgetsList, ReportWidgetFactory $factory)
+    {
+        $widget = $factory->createWidget()->setName('Provider_WidgetProviders');
+        $widgetsList->addWidgetConfig($widget);
     }
 
     public function configureView(ViewDataTable $view)
