@@ -12,6 +12,7 @@ use Piwik\ArchiveProcessor;
 use Piwik\Common;
 use Piwik\Piwik;
 use Piwik\Plugins\CoreVisualizations\Visualizations\HtmlTable;
+use Piwik\Plugins\SitesManager\SiteUrls;
 
 /**
  * @see plugins/Referrers/functions.php
@@ -31,9 +32,18 @@ class Referrers extends \Piwik\Plugin
             'Insights.addReportToOverview'      => 'addReportToInsightsOverview',
             'Live.getAllVisitorDetails'         => 'extendVisitorDetails',
             'Request.getRenamedModuleAndAction' => 'renameDeprecatedModuleAndAction',
+            'Tracker.setTrackerCacheGeneral'    => 'setTrackerCacheGeneral'
         );
     }
 
+    public function setTrackerCacheGeneral(&$cacheContent)
+    {
+        $siteUrls = new SiteUrls();
+        $urls = $siteUrls->getAllCachedSiteUrls();
+
+        return $cacheContent['allUrlsByHostAndIdSite'] = $siteUrls->groupUrlsByHost($urls);
+    }
+
     public function renameDeprecatedModuleAndAction(&$module, &$action)
     {
         if($module == 'Referers') {
@@ -96,6 +106,6 @@ class Referrers extends \Piwik\Plugin
         $label = strtolower(Piwik::translate($indexTranslation));
 
         // return html that displays it as grey & italic
-        return '<span class="datatable-label-category"><em>(' . $label . ')</em></span>';
+        return '<span class="datatable-label-category">(' . $label . ')</span>';
     }
 }
