@@ -24,8 +24,8 @@ class GetCampaigns extends Base
         $this->actionToLoadSubTables = 'getKeywordsFromCampaignId';
         $this->hasGoalMetrics = true;
         $this->order = 9;
-        $this->widgetTitle  = 'Referrers_Campaigns';
-        $this->menuTitle    = 'Referrers_Campaigns';
+
+        $this->subcategoryId = 'Referrers_Campaigns';
     }
 
     public function configureView(ViewDataTable $view)
