@@ -23,7 +23,6 @@ class Resolution extends \Piwik\Plugin
     {
         return array(
             'Live.getAllVisitorDetails'            => 'extendVisitorDetails',
-            'Request.getRenamedModuleAndAction' => 'renameUserSettingsModuleAndAction',
         );
     }
 
@@ -33,11 +32,4 @@ class Resolution extends \Piwik\Plugin
 
         $visitor['resolution']               = $instance->getResolution();
     }
-
-    public function renameUserSettingsModuleAndAction(&$module, &$action)
-    {
-        if ($module == 'UserSettings' && ($action == 'getResolution' || $action == 'getConfiguration')) {
-            $module = 'Resolution';
-        }
-    }
 }
