@@ -7,6 +7,18 @@
 
 Segmentation = (function($) {
 
+    Mousetrap.bind('s', function (event) {
+        if (event.altKey) {
+            return;
+        }
+        if (event.preventDefault) {
+            event.preventDefault();
+        } else {
+            event.returnValue = false; // IE
+        }
+        $('.segmentListContainer .segmentationContainer .title').trigger('click').focus();
+    });
+
     function preselectFirstMetricMatch(rowNode)
     {
         var matchValue = $(rowNode).find('.metricMatchBlock option:first').attr('value');
@@ -58,39 +70,61 @@ Segmentation = (function($) {
 
         segmentation.prototype.getSegment = function(){
             var self = this;
-            if($.browser.mozilla) {
-                return self.currentSegmentStr;
-            }
-            return decodeURIComponent(self.currentSegmentStr);
+            return self.currentSegmentStr;
         };
 
         segmentation.prototype.setSegment = function(segmentStr){
-            if(!$.browser.mozilla) {
-                segmentStr = encodeURIComponent(segmentStr);
-            }
             this.currentSegmentStr = segmentStr;
         };
 
+        segmentation.prototype.setTooltip = function (segmentDescription) {
+
+            var title = _pk_translate('SegmentEditor_ChooseASegment') + '.';
+            title += ' '+ _pk_translate('SegmentEditor_CurrentlySelectedSegment', [segmentDescription]);
+
+            $(this.content).attr('title', title);
+        };
+
         segmentation.prototype.markCurrentSegment = function(){
             var current = this.getSegment();
 
             var segmentationTitle = $(this.content).find(".segmentationTitle");
+            var title;
             if( current != "")
             {
-                var currentDecoded = piwikHelper.htmlDecode(current);
-                var selector = 'div.segmentList ul li[data-definition="'+currentDecoded+'"]';
+                // this code is mad, and may drive you mad.
+                // the whole segmentation editor needs to be rewritten in AngularJS with clean code
+                var selector = 'div.segmentList ul li[data-definition="'+current+'"]';
                 var foundItems = $(selector, this.target);
 
-                if( foundItems.length > 0) {
+                if (foundItems.length === 0) {
+                    try {
+                        currentDecoded = piwikHelper.htmlDecode(current);
+                        selector = 'div.segmentList ul li[data-definition="'+currentDecoded+'"]';
+                        foundItems = $(selector, this.target);
+                    } catch(e) {}
+                }
+                if (foundItems.length === 0) {
+                    try {
+                        currentDecoded = piwikHelper.htmlDecode(decodeURIComponent(current));
+                        selector = 'div.segmentList ul li[data-definition="'+currentDecoded+'"]';
+                        foundItems = $(selector, this.target);
+                    } catch(e) {}
+                }
+
+                if (foundItems.length > 0) {
                     var idSegment = $(foundItems).first().attr('data-idsegment');
-                    var title = getSegmentName( getSegmentFromId(idSegment));
+                    title = getSegmentName(getSegmentFromId(idSegment));
                 } else {
                     title = _pk_translate('SegmentEditor_CustomSegment');
                 }
                 segmentationTitle.addClass('segment-clicked').html( title );
+                this.setTooltip(title);
             }
             else {
-                $(this.content).find(".segmentationTitle").text(this.translations['SegmentEditor_DefaultAllVisits']);
+                title = this.translations['SegmentEditor_DefaultAllVisits'];
+                segmentationTitle.text(title);
+                this.setTooltip(title);
             }
         };
 
@@ -117,8 +151,7 @@ Segmentation = (function($) {
         };
 
         var getMockedInputRowHtml = function(){
-            var mockedInputRow = '<div class="segment-row"><a class="segment-close" href="#"></a><div class="segment-row-inputs">'+getMockedInputSet().html()+'</div></div>';
-            return mockedInputRow;
+            return '<div class="segment-row"><a class="segment-close" href="#"></a><div class="segment-row-inputs">'+getMockedInputSet().html()+'</div></div>';
         };
 
         var getMockedFormRow = function(){
@@ -199,7 +232,7 @@ Segmentation = (function($) {
             var html = self.editorTemplate.find("> .listHtml").clone();
             var segment, injClass;
             var listHtml = '<li data-idsegment="" ' +
-                (self.currentSegmentStr == "" ? " class='segmentSelected' " : "")
+                (self.currentSegmentStr == "" ? " class='segmentSelected' tabindex='4' " : "")
                 + ' data-definition=""><span class="segname">' + self.translations['SegmentEditor_DefaultAllVisits']
                 + ' ' + self.translations['General_DefaultAppended']
                 + '</span></li> ';
@@ -237,15 +270,14 @@ Segmentation = (function($) {
 
                     injClass = "";
                     var checkSelected = segment.definition;
-                    if(!$.browser.mozilla) {
-                        checkSelected = encodeURIComponent(checkSelected);
-                    }
 
-                    if( checkSelected == self.currentSegmentStr){
+                    if( checkSelected == self.currentSegmentStr ||
+                        checkSelected == decodeURIComponent(self.currentSegmentStr)
+                    ) {
                         injClass = 'class="segmentSelected"';
                     }
                     listHtml += '<li data-idsegment="'+segment.idsegment+'" data-definition="'+ (segment.definition).replace(/"/g, '&quot;') +'" '
-                        +injClass+' title="'+ getSegmentTooltipEnrichedWithUsername(segment) +'"><span class="segname">'+getSegmentName(segment)+'</span>';
+                        +injClass+' title="'+ getSegmentTooltipEnrichedWithUsername(segment) +'"><span class="segname" tabindex="4">'+getSegmentName(segment)+'</span>';
                     if(self.segmentAccess == "write") {
                         listHtml += '<span class="editSegment" title="'+ self.translations['General_Edit'].toLocaleLowerCase() +'"></span>';
                     }
@@ -311,7 +343,7 @@ Segmentation = (function($) {
         var sanitiseSegmentName = function(segment) {
             segment = piwikHelper.escape(segment);
             return segment;
-        }
+        };
 
         var getFormHtml = function() {
             var html = self.editorTemplate.find("> .segment-element").clone();
@@ -505,7 +537,11 @@ Segmentation = (function($) {
                     var idsegment = $(this).attr("data-idsegment");
                     segmentDefinition = $(this).data("definition");
 
-                    self.setSegment(segmentDefinition);
+                    if (!piwikHelper.isAngularRenderingThePage()) {
+                        // we update segment on location change success
+                        self.setSegment(segmentDefinition);
+                    }
+
                     self.markCurrentSegment();
                     self.segmentSelectMethod( segmentDefinition );
                     toggleLoadingMessage(segmentDefinition.length);
@@ -513,6 +549,14 @@ Segmentation = (function($) {
             });
 
             self.target.on('click', '.add_new_segment', function (e) {
+
+                var parameters = {isAllowed: true};
+                var $rootScope = piwikHelper.getAngularDependency('$rootScope');
+                $rootScope.$emit('Segmentation.initAddSegment', parameters);
+                if (parameters && !parameters.isAllowed) {
+                    return;
+                }
+
                 e.stopPropagation();
                 displayFormAddNewSegment(e);
             });
@@ -568,10 +612,6 @@ Segmentation = (function($) {
             // segment editor form events
             //
 
-            self.target.on('click', ".segment-element a:not(.crowdfundingLink)", function (e) {
-                e.preventDefault();
-            });
-
             self.target.on('click',  "a.editSegmentName", function (e) {
                 var oldName = $(e.currentTarget).parents("h3").find("span").text();
                 $(e.currentTarget).parents("h3").find("span").hide();
@@ -653,9 +693,9 @@ Segmentation = (function($) {
                 var params = {
                     "idsegment" : segmentId
                 };
-                $('.segment-delete-confirm', self.target).find('#name').text( segmentName );
+                $('#segment-delete-confirm').find('#name').text( segmentName );
                 if(segmentId != ""){
-                    piwikHelper.modalConfirm(self.target.find('.segment-delete-confirm'), {
+                    piwikHelper.modalConfirm($('#segment-delete-confirm'), {
                         yes: function(){
                             self.deleteMethod(params);
                         }
@@ -972,9 +1012,12 @@ Segmentation = (function($) {
             }
             // remove any remaining forms
 
+
             self.form = getFormHtml();
             self.target.prepend(self.form);
 
+            piwikHelper.setMarginLeftToBeInViewport(self.form);
+
             // if there's enough space to the left & not enough space to the right,
             // anchor the form to the right of the selector
             if (self.form.width() + self.target.offset().left > $(window).width()
@@ -1006,12 +1049,6 @@ Segmentation = (function($) {
                 parseFormAndSave();
             });
 
-            $(self.form).find('.segment-footer').hover( function() {
-                $('.segmentFooterNote', self.target).fadeIn();
-            }, function() {
-                $('.segmentFooterNote', self.target).fadeOut();
-            });
-
             if(typeof mode !== "undefined" && mode == "new")
             {
                 $(self.form).find(".editSegmentName").trigger('click');
@@ -1197,6 +1234,24 @@ Segmentation = (function($) {
             toggleLoadingMessage(segmentIsSet);
         };
 
+        if (piwikHelper.isAngularRenderingThePage()) {
+            angular.element(document).injector().invoke(function ($rootScope, $location) {
+                $rootScope.$on('$locationChangeSuccess', function () {
+                    var $search = $location.search();
+
+                    var segment = '';
+                    if ('undefined' !== typeof $search.segment && null !== $search.segment) {
+                        segment = $search.segment
+                    }
+
+                    if (self.getSegment() != segment) {
+                        self.setSegment(segment);
+                        self.initHtml();
+                    }
+                });
+            });
+        }
+
         this.initHtml();
         bindEvents();
     };
@@ -1227,9 +1282,38 @@ $(document).ready(function() {
         }
 
         var self = this;
-        this.changeSegment = function(segmentDefinition) {
+
+        this.uriEncodeSegmentDefinition = function (segmentDefinition) {
             segmentDefinition = cleanupSegmentDefinition(segmentDefinition);
             segmentDefinition = encodeURIComponent(segmentDefinition);
+            return segmentDefinition;
+        };
+
+        this.changeSegment = function(segmentDefinition) {
+            if (piwikHelper.isAngularRenderingThePage()) {
+                angular.element(document).injector().invoke(function ($location, $rootScope) {
+                    var $search = $location.search();
+
+                    if (segmentDefinition !== $search.segment) {
+                        // eg when using back button the date might be actually already changed in the URL and we do not
+                        // want to change the URL again
+                        $search.segment = segmentDefinition.replace(/%$/, '%25').replace(/%([^\d].)/g, "%25$1");
+                        $location.search($search);
+                        setTimeout(function () {
+                            try {
+                                $rootScope.$apply();
+                            } catch (e) {}
+                        }, 1);
+                    }
+                });
+                return false;
+            } else {
+                return this.forceSegmentReload(segmentDefinition);
+            }
+        };
+
+        this.forceSegmentReload = function (segmentDefinition) {
+            segmentDefinition = this.uriEncodeSegmentDefinition(segmentDefinition);
             return broadcast.propagateNewPage('segment=' + segmentDefinition, true);
         };
 
@@ -1260,16 +1344,15 @@ $(document).ready(function() {
                     self.props.availableSegments.push(params);
                     self.rebuild();
 
-                    self.impl.setSegment(params.definition);
                     self.impl.markCurrentSegment();
 
                     self.$element.find('a.close').click();
-                    self.changeSegment(params.definition);
+                    self.forceSegmentReload(params.definition);
 
                     self.changeSegmentList(self.props.availableSegments);
                 }
             });
-            ajaxHandler.send(true);
+            ajaxHandler.send();
         };
 
         var updateSegment = function(params){
@@ -1299,16 +1382,15 @@ $(document).ready(function() {
                     $.extend( self.props.availableSegments[idx], params);
                     self.rebuild();
 
-                    self.impl.setSegment(params.definition);
                     self.impl.markCurrentSegment();
 
                     self.$element.find('a.close').click();
-                    self.changeSegment(params.definition);
+                    self.forceSegmentReload(params.definition);
 
                     self.changeSegmentList(self.props.availableSegments);
                 }
             });
-            ajaxHandler.send(true);
+            ajaxHandler.send();
         };
 
         var deleteSegment = function(params){
@@ -1341,23 +1423,38 @@ $(document).ready(function() {
                     self.rebuild();
 
                     self.$element.find('a.close').click();
-                    self.changeSegment('');
+                    self.forceSegmentReload('');
+
                     $('.ui-dialog-content').dialog('close');
 
                     self.changeSegmentList(self.props.availableSegments);
                 }
             });
 
-            ajaxHandler.send(true);
+            ajaxHandler.send();
         };
 
-        var segmentFromRequest = encodeURIComponent(self.props.selectedSegment)
-            || broadcast.getValueFromHash('segment')
-            || broadcast.getValueFromUrl('segment');
-        if($.browser.mozilla) {
+        function getSegmentFromRequest()
+        {
+            var hashStr = broadcast.getHashFromUrl();
+            var segmentFromRequest;
+
+            if (hashStr && hashStr.indexOf('segment=') !== -1) {
+                // needed in case "segment = ''" in hash but set in query via 'segment=foo==bar'.
+                segmentFromRequest = broadcast.getValueFromHash('segment');
+            } else {
+                segmentFromRequest = broadcast.getValueFromHash('segment')
+                    || encodeURIComponent(self.props.selectedSegment)
+                    || broadcast.getValueFromUrl('segment');
+            }
+
             segmentFromRequest = decodeURIComponent(segmentFromRequest);
+
+            return segmentFromRequest;
         }
 
+        var segmentFromRequest = getSegmentFromRequest();
+
         var userSegmentAccess = (this.props.authorizedToCreateSegments) ? "write" : "read";
 
         this.impl = new Segmentation({
@@ -1368,7 +1465,7 @@ $(document).ready(function() {
             "addMethod": addSegment,
             "updateMethod": updateSegment,
             "deleteMethod": deleteSegment,
-            "segmentSelectMethod": function () { self.changeSegment.apply(this, arguments); },
+            "segmentSelectMethod": function () { self.changeSegment.apply(self, arguments); },
             "currentSegmentStr": segmentFromRequest,
             "translations": this.props.segmentTranslations
         });
