@@ -13,12 +13,14 @@ use Piwik\Access;
 use Piwik\Common;
 use Piwik\Container\StaticContainer;
 use Piwik\Date;
-use Piwik\Db;
-use Piwik\Metrics\Formatter;
 use Piwik\Network\IPUtils;
 use Piwik\Option;
 use Piwik\Piwik;
-use Piwik\Measurable\MeasurableSettings;
+use Piwik\Plugin\SettingsProvider;
+use Piwik\Plugins\CorePluginsAdmin\SettingsMetadata;
+use Piwik\Plugins\WebsiteMeasurable\Settings\Urls;
+use Piwik\Settings\Measurable\MeasurableProperty;
+use Piwik\Settings\Measurable\MeasurableSettings;
 use Piwik\ProxyHttp;
 use Piwik\Scheduler\Scheduler;
 use Piwik\SettingsPiwik;
@@ -60,6 +62,28 @@ class API extends \Piwik\Plugin\API
     const OPTION_SITE_SPECIFIC_USER_AGENT_EXCLUDE_ENABLE = 'SitesManager_EnableSiteSpecificUserAgentExclude';
     const OPTION_KEEP_URL_FRAGMENTS_GLOBAL = 'SitesManager_KeepURLFragmentsGlobal';
 
+    /**
+     * @var SettingsProvider
+     */
+    private $settingsProvider;
+
+    /**
+     * @var SettingsMetadata
+     */
+    private $settingsMetadata;
+
+    /**
+     * @var Type\TypeManager
+     */
+    private $typeManager;
+
+    public function __construct(SettingsProvider $provider, SettingsMetadata $settingsMetadata, Type\TypeManager $typeManager)
+    {
+        $this->settingsProvider = $provider;
+        $this->settingsMetadata = $settingsMetadata;
+        $this->typeManager = $typeManager;
+    }
+
     /**
      * Returns the javascript tag for the given idSite.
      * This tag must be included on every page to be tracked by Piwik
@@ -75,12 +99,14 @@ class API extends \Piwik\Plugin\API
      * @param bool $customCampaignKeywordParam
      * @param bool $doNotTrack
      * @param bool $disableCookies
+     * @param bool $trackNoScript
      * @return string The Javascript tag ready to be included on the HTML pages
      */
     public function getJavascriptTag($idSite, $piwikUrl = '', $mergeSubdomains = false, $groupPageTitlesByDomain = false,
                                      $mergeAliasUrls = false, $visitorCustomVariables = false, $pageCustomVariables = false,
                                      $customCampaignNameQueryParam = false, $customCampaignKeywordParam = false,
-                                     $doNotTrack = false, $disableCookies = false)
+                                     $doNotTrack = false, $disableCookies = false, $trackNoScript = false,
+                                     $crossDomain = false)
     {
         Piwik::checkUserHasViewAccess($idSite);
 
@@ -100,7 +126,7 @@ class API extends \Piwik\Plugin\API
         $code = $generator->generate($idSite, $piwikUrl, $mergeSubdomains, $groupPageTitlesByDomain,
                                      $mergeAliasUrls, $visitorCustomVariables, $pageCustomVariables,
                                      $customCampaignNameQueryParam, $customCampaignKeywordParam,
-                                     $doNotTrack, $disableCookies);
+                                     $doNotTrack, $disableCookies, $trackNoScript, $crossDomain);
         $code = str_replace(array('<br>', '<br />', '<br/>'), '', $code);
         return $code;
     }
@@ -330,7 +356,7 @@ class API extends \Piwik\Plugin\API
      * For the superUser it returns all the websites in the database.
      *
      * @param bool|int $limit Specify max number of sites to return
-     * @param bool $_restrictSitesToLogin Hack necessary when runnning scheduled tasks, where "Super User" is forced, but sometimes not desired, see #3017
+     * @param bool $_restrictSitesToLogin Hack necessary when running scheduled tasks, where "Super User" is forced, but sometimes not desired, see #3017
      * @return array array for each site, an array of information (idsite, name, main_url, etc.)
      */
     public function getSitesWithAtLeastViewAccess($limit = false, $_restrictSitesToLogin = false)
@@ -491,6 +517,7 @@ class API extends \Piwik\Plugin\API
      * @param array|string $urls The URLs array must contain at least one URL called the 'main_url' ;
      *                        if several URLs are provided in the array, they will be recorded
      *                        as Alias URLs for this website.
+     *                        When calling API via HTTP specify multiple URLs via `&urls[]=http...&urls[]=http...`.
      * @param int $ecommerce Is Ecommerce Reporting enabled for this website?
      * @param null $siteSearch
      * @param string $searchKeywordParameters Comma separated list of search keyword parameter names
@@ -504,7 +531,7 @@ class API extends \Piwik\Plugin\API
      * @param null|string $excludedUserAgents
      * @param int $keepURLFragments If 1, URL fragments will be kept when tracking. If 2, they
      *                              will be removed. If 0, the default global behavior will be used.
-     * @param array|null $settings JSON serialized settings eg {settingName: settingValue, ...}
+     * @param array|null $settingValues JSON serialized settings eg {settingName: settingValue, ...}
      * @see getKeepURLFragmentsGlobal.
      * @param string $type The website type, defaults to "website" if not set.
      * @param bool|null $excludeUnknownUrls Track only URL matching one of website URLs
@@ -512,7 +539,7 @@ class API extends \Piwik\Plugin\API
      * @return int the website ID created
      */
     public function addSite($siteName,
-                            $urls,
+                            $urls = null,
                             $ecommerce = null,
                             $siteSearch = null,
                             $searchKeywordParameters = null,
@@ -526,20 +553,29 @@ class API extends \Piwik\Plugin\API
                             $excludedUserAgents = null,
                             $keepURLFragments = null,
                             $type = null,
-                            $settings = null,
+                            $settingValues = null,
                             $excludeUnknownUrls = null)
     {
         Piwik::checkUserHasSuperUserAccess();
 
         $this->checkName($siteName);
-        $urls = $this->cleanParameterUrls($urls);
-        $this->checkUrls($urls);
-        $this->checkAtLeastOneUrl($urls);
-        $siteSearch = $this->checkSiteSearch($siteSearch);
-        list($searchKeywordParameters, $searchCategoryParameters) = $this->checkSiteSearchParameters($searchKeywordParameters, $searchCategoryParameters);
 
-        $keepURLFragments = (int)$keepURLFragments;
-        self::checkKeepURLFragmentsValue($keepURLFragments);
+        if (!isset($settingValues)) {
+            $settingValues = array();
+        }
+
+        $coreProperties = array();
+        $coreProperties = $this->setSettingValue('urls', $urls, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('ecommerce', $ecommerce, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('group', $group, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('sitesearch', $siteSearch, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('sitesearch_keyword_parameters', explode(',', $searchKeywordParameters), $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('sitesearch_category_parameters', explode(',', $searchCategoryParameters), $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('keep_url_fragment', $keepURLFragments, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('exclude_unknown_urls', $excludeUnknownUrls, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('excluded_ips', explode(',', $excludedIps), $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('excluded_parameters', explode(',', $excludedQueryParameters), $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('excluded_user_agents', explode(',', $excludedUserAgents), $coreProperties, $settingValues);
 
         $timezone = trim($timezone);
         if (empty($timezone)) {
@@ -552,23 +588,10 @@ class API extends \Piwik\Plugin\API
         }
         $this->checkValidCurrency($currency);
 
-        $url  = $urls[0];
-        $urls = array_slice($urls, 1);
-
-        $bind = array('name'     => $siteName,
-                      'main_url' => $url);
-
-        $bind['exclude_unknown_urls'] = (int)$excludeUnknownUrls;
-        $bind['excluded_ips'] = $this->checkAndReturnExcludedIps($excludedIps);
-        $bind['excluded_parameters']  = $this->checkAndReturnCommaSeparatedStringList($excludedQueryParameters);
-        $bind['excluded_user_agents'] = $this->checkAndReturnCommaSeparatedStringList($excludedUserAgents);
-        $bind['keep_url_fragment']    = $keepURLFragments;
+        $bind = array('name' => $siteName);
         $bind['timezone']   = $timezone;
         $bind['currency']   = $currency;
-        $bind['ecommerce']  = (int)$ecommerce;
-        $bind['sitesearch'] = $siteSearch;
-        $bind['sitesearch_keyword_parameters']  = $searchKeywordParameters;
-        $bind['sitesearch_category_parameters'] = $searchCategoryParameters;
+        $bind['main_url']   = '';
 
         if (is_null($startDate)) {
             $bind['ts_created'] = Date::now()->getDatetime();
@@ -584,21 +607,41 @@ class API extends \Piwik\Plugin\API
             $bind['group'] = "";
         }
 
-        if (!empty($settings)) {
-            $this->validateMeasurableSettings(0, $bind['type'], $settings);
+        $allSettings = $this->setAndValidateMeasurableSettings(0, 'website', $coreProperties);
+
+        // any setting specified in setting values will overwrite other setting
+        if (!empty($settingValues)) {
+            $this->setAndValidateMeasurableSettings(0, $bind['type'], $settingValues);
+        }
+
+        foreach ($allSettings as $settings) {
+            foreach ($settings->getSettingsWritableByCurrentUser() as $setting) {
+                $name = $setting->getName();
+                if ($setting instanceof MeasurableProperty && $name !== 'urls') {
+                    $default = $setting->getDefaultValue();
+                    if (is_bool($default)) {
+                        $default = (int) $default;
+                    } elseif (is_array($default)) {
+                        $default = implode(',', $default);
+                    }
+
+                    $bind[$name] = $default;
+                }
+            }
         }
 
         $idSite = $this->getModel()->createSite($bind);
 
-        $this->insertSiteUrls($idSite, $urls);
+        if (!empty($coreProperties)) {
+            $this->saveMeasurableSettings($idSite, 'website', $coreProperties);
+        }
+        if (!empty($settingValues)) {
+            $this->saveMeasurableSettings($idSite, $bind['type'], $settingValues);
+        }
 
         // we reload the access list which doesn't yet take in consideration this new website
         Access::getInstance()->reloadAccess();
 
-        if (!empty($settings)) {
-            $this->updateMeasurableSettings($idSite, $settings);
-        }
-
         $this->postUpdateWebsite($idSite);
 
         /**
@@ -611,34 +654,64 @@ class API extends \Piwik\Plugin\API
         return (int) $idSite;
     }
 
-    private function validateMeasurableSettings($idSite, $idType, $settings)
+    private function setSettingValue($fieldName, $value, $coreProperties, $settingValues)
     {
-        $measurableSettings = new MeasurableSettings($idSite, $idType);
+        $pluginName = 'WebsiteMeasurable';
 
-        foreach ($measurableSettings->getSettingsForCurrentUser() as $measurableSetting) {
-            $name = $measurableSetting->getName();
-            if (!empty($settings[$name])) {
-                $measurableSetting->setValue($settings[$name]);
+        if (isset($value)) {
+
+            if (empty($coreProperties[$pluginName])) {
+                $coreProperties[$pluginName] = array();
+            }
+
+            $coreProperties[$pluginName][] = array('name' => $fieldName, 'value' => $value);
+
+        } elseif (!empty($settingValues[$pluginName])) {
+            // we check if the value is defined in the setting values instead
+            foreach ($settingValues[$pluginName] as $key => $setting) {
+                if ($setting['name'] === $fieldName) {
+
+                    if (empty($coreProperties[$pluginName])) {
+                        $coreProperties[$pluginName] = array();
+                    }
+
+                    $coreProperties[$pluginName][] = array('name' => $fieldName, 'value' => $setting['value']);
+                    return $coreProperties;
+                }
             }
         }
+
+        return $coreProperties;
     }
 
-    private function updateMeasurableSettings($idSite, $settings)
+    public function getSiteSettings($idSite)
     {
-        $idType = Site::getTypeFor($idSite);
+        Piwik::checkUserHasAdminAccess($idSite);
 
-        $measurableSettings = new MeasurableSettings($idSite, $idType);
+        $measurableSettings = $this->settingsProvider->getAllMeasurableSettings($idSite, $idMeasurableType = false);
 
-        foreach ($measurableSettings->getSettingsForCurrentUser() as $measurableSetting) {
-            $name = $measurableSetting->getName();
-            if (!empty($settings[$name])) {
-                $measurableSetting->setValue($settings[$name]);
-            }
-            // we do not clear existing settings if the value is missing.
-            // There can be so many settings added by random plugins one would always clear some settings.
+        return $this->settingsMetadata->formatSettings($measurableSettings);
+    }
+
+    private function setAndValidateMeasurableSettings($idSite, $idType, $settingValues)
+    {
+        $measurableSettings = $this->settingsProvider->getAllMeasurableSettings($idSite, $idType);
+
+        $this->settingsMetadata->setPluginSettings($measurableSettings, $settingValues);
+
+        return $measurableSettings;
+    }
+
+    /**
+     * @param MeasurableSettings[] $measurableSettings
+     */
+    private function saveMeasurableSettings($idSite, $idType, $settingValues)
+    {
+        $measurableSettings = $this->setAndValidateMeasurableSettings($idSite, $idType, $settingValues);
+
+        foreach ($measurableSettings as $measurableSetting) {
+            $measurableSetting->save();
         }
-
-        $measurableSettings->save();
     }
 
     private function postUpdateWebsite($idSite)
@@ -650,7 +723,9 @@ class API extends \Piwik\Plugin\API
     }
 
     /**
-     * Delete a website from the database, given its Id.
+     * Delete a website from the database, given its Id. The method deletes the actual site as well as some associated
+     * data. However, it does not delete any logs or archives that belong to this website. You can delete logs and
+     * archives for a site manually as described in this FAQ: http://piwik.org/faq/how-to/faq_73/ .
      *
      * Requires Super User access.
      *
@@ -684,21 +759,6 @@ class API extends \Piwik\Plugin\API
         Piwik::postEvent('SitesManager.deleteSite.end', array($idSite));
     }
 
-    /**
-     * Checks that the array has at least one element
-     *
-     * @param array $urls
-     * @throws Exception
-     */
-    private function checkAtLeastOneUrl($urls)
-    {
-        if (!is_array($urls)
-            || count($urls) == 0
-        ) {
-            throw new Exception(Piwik::translate("SitesManager_ExceptionNoUrl"));
-        }
-    }
-
     private function checkValidTimezone($timezone)
     {
         $timezones = $this->getTimezonesList();
@@ -767,22 +827,33 @@ class API extends \Piwik\Plugin\API
      * they won't be duplicated. The 'main_url' of the website won't be affected by this method.
      *
      * @param int $idSite
-     * @param array|string $urls
+     * @param array|string $urls When calling API via HTTP specify multiple URLs via `&urls[]=http...&urls[]=http...`.
      * @return int the number of inserted URLs
      */
     public function addSiteAliasUrls($idSite, $urls)
     {
         Piwik::checkUserHasAdminAccess($idSite);
 
-        $urls = $this->cleanParameterUrls($urls);
-        $this->checkUrls($urls);
+        if (empty($urls)) {
+            return 0;
+        }
+
+        if (!is_array($urls)) {
+            $urls = array($urls);
+        }
 
         $urlsInit = $this->getSiteUrlsFromId($idSite);
-        $toInsert = array_diff($urls, $urlsInit);
-        $this->insertSiteUrls($idSite, $toInsert);
+        $toInsert = array_merge($urlsInit, $urls);
+
+        $urlsProperty = new Urls($idSite);
+        $urlsProperty->setValue($toInsert);
+        $urlsProperty->save();
+
+        $inserted = array_diff($urlsProperty->getValue(), $urlsInit);
+
         $this->postUpdateWebsite($idSite);
 
-        return count($toInsert);
+        return count($inserted);
     }
 
     /**
@@ -797,14 +868,18 @@ class API extends \Piwik\Plugin\API
     {
         Piwik::checkUserHasAdminAccess($idSite);
 
-        $urls = $this->cleanParameterUrls($urls);
-        $this->checkUrls($urls);
+        $mainUrl = Site::getMainUrlFor($idSite);
+        array_unshift($urls, $mainUrl);
+
+        $urlsProperty = new Urls($idSite);
+        $urlsProperty->setValue($urls);
+        $urlsProperty->save();
+
+        $inserted = array_diff($urlsProperty->getValue(), $urls);
 
-        $this->getModel()->deleteSiteAliasUrls($idSite);
-        $this->insertSiteUrls($idSite, $urls);
         $this->postUpdateWebsite($idSite);
 
-        return count($urls);
+        return count($inserted);
     }
 
     /**
@@ -1077,6 +1152,7 @@ class API extends \Piwik\Plugin\API
      * @param int $idSite website ID defining the website to edit
      * @param string $siteName website name
      * @param string|array $urls the website URLs
+     *                           When calling API via HTTP specify multiple URLs via `&urls[]=http...&urls[]=http...`.
      * @param int $ecommerce Whether Ecommerce is enabled, 0 or 1
      * @param null|int $siteSearch Whether site search is enabled, 0 or 1
      * @param string $searchKeywordParameters Comma separated list of search keyword parameter names
@@ -1091,7 +1167,7 @@ class API extends \Piwik\Plugin\API
      * @param int|null $keepURLFragments If 1, URL fragments will be kept when tracking. If 2, they
      *                                   will be removed. If 0, the default global behavior will be used.
      * @param string $type The Website type, default value is "website"
-     * @param array|null $settings JSON serialized settings eg {settingName: settingValue, ...}
+     * @param array|null $settingValues JSON serialized settings eg {settingName: settingValue, ...}
      * @param bool|null $excludeUnknownUrls Track only URL matching one of website URLs
      * @throws Exception
      * @see getKeepURLFragmentsGlobal. If null, the existing value will
@@ -1115,7 +1191,7 @@ class API extends \Piwik\Plugin\API
                                $excludedUserAgents = null,
                                $keepURLFragments = null,
                                $type = null,
-                               $settings = null,
+                               $settingValues = null,
                                $excludeUnknownUrls = null)
     {
         Piwik::checkUserHasAdminAccess($idSite);
@@ -1134,71 +1210,67 @@ class API extends \Piwik\Plugin\API
             $bind['name'] = $siteName;
         }
 
-        if (!is_null($urls)) {
-            $urls = $this->cleanParameterUrls($urls);
-            $this->checkUrls($urls);
-            $this->checkAtLeastOneUrl($urls);
-            $url = $urls[0];
-            $bind['main_url'] = $url;
+        if (!isset($settingValues)) {
+            $settingValues = array();
         }
 
-        if (!is_null($currency)) {
+        if (empty($coreProperties)) {
+            $coreProperties = array();
+        }
+
+        $coreProperties = $this->setSettingValue('urls', $urls, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('group', $group, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('ecommerce', $ecommerce, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('sitesearch', $siteSearch, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('sitesearch_keyword_parameters', explode(',', $searchKeywordParameters), $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('sitesearch_category_parameters', explode(',', $searchCategoryParameters), $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('keep_url_fragment', $keepURLFragments, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('exclude_unknown_urls', $excludeUnknownUrls, $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('excluded_ips', explode(',', $excludedIps), $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('excluded_parameters', explode(',', $excludedQueryParameters), $coreProperties, $settingValues);
+        $coreProperties = $this->setSettingValue('excluded_user_agents', explode(',', $excludedUserAgents), $coreProperties, $settingValues);
+
+        if (isset($currency)) {
             $currency = trim($currency);
             $this->checkValidCurrency($currency);
             $bind['currency'] = $currency;
         }
-        if (!is_null($timezone)) {
+        if (isset($timezone)) {
             $timezone = trim($timezone);
             $this->checkValidTimezone($timezone);
             $bind['timezone'] = $timezone;
         }
-        if (!is_null($group)
+        if (isset($group)
             && Piwik::hasUserSuperUserAccess()
         ) {
             $bind['group'] = trim($group);
         }
-        if (!is_null($ecommerce)) {
-            $bind['ecommerce'] = (int)(bool)$ecommerce;
-        }
-        if (!is_null($startDate)) {
+        if (isset($startDate)) {
             $bind['ts_created'] = Date::factory($startDate)->getDatetime();
         }
-        $bind['exclude_unknown_urls'] = (int)$excludeUnknownUrls;
-        $bind['excluded_ips'] = $this->checkAndReturnExcludedIps($excludedIps);
-        $bind['excluded_parameters'] = $this->checkAndReturnCommaSeparatedStringList($excludedQueryParameters);
-        $bind['excluded_user_agents'] = $this->checkAndReturnCommaSeparatedStringList($excludedUserAgents);
 
-        if (!is_null($keepURLFragments)) {
-            $keepURLFragments = (int)$keepURLFragments;
-            self::checkKeepURLFragmentsValue($keepURLFragments);
-
-            $bind['keep_url_fragment'] = $keepURLFragments;
-        }
-
-        $bind['sitesearch'] = $this->checkSiteSearch($siteSearch);
-        list($searchKeywordParameters, $searchCategoryParameters) = $this->checkSiteSearchParameters($searchKeywordParameters, $searchCategoryParameters);
-        $bind['sitesearch_keyword_parameters'] = $searchKeywordParameters;
-        $bind['sitesearch_category_parameters'] = $searchCategoryParameters;
-
-        if (!is_null($type)) {
+        if (isset($type)) {
             $bind['type'] = $this->checkAndReturnType($type);
         }
 
-        if (!empty($settings)) {
-            $this->validateMeasurableSettings($idSite, Site::getTypeFor($idSite), $settings);
+        if (!empty($coreProperties)) {
+            $this->setAndValidateMeasurableSettings($idSite, $idType = 'website', $coreProperties);
         }
 
-        $this->getModel()->updateSite($bind, $idSite);
-
-        if (!empty($settings)) {
-            $this->updateMeasurableSettings($idSite, $settings);
+        if (!empty($settingValues)) {
+            $this->setAndValidateMeasurableSettings($idSite, $idType = null, $settingValues);
         }
 
-        // we now update the main + alias URLs
-        $this->getModel()->deleteSiteAliasUrls($idSite);
+        if (!empty($bind)) {
+            $this->getModel()->updateSite($bind, $idSite);
+        }
 
-        if (count($urls) > 1) {
-            $this->addSiteAliasUrls($idSite, array_slice($urls, 1));
+        if (!empty($coreProperties)) {
+            $this->saveMeasurableSettings($idSite, $idType = 'website', $coreProperties);
+        }
+
+        if (!empty($settingValues)) {
+            $this->saveMeasurableSettings($idSite, $idType = null, $settingValues);
         }
 
         $this->postUpdateWebsite($idSite);
@@ -1208,7 +1280,7 @@ class API extends \Piwik\Plugin\API
      * Updates the field ts_created for the specified websites.
      *
      * @param $idSites int Id Site to update ts_created
-     * @param $minDate Date to set as creation date. To play it safe it will substract one more day.
+     * @param $minDate Date to set as creation date. To play it safe it will subtract one more day.
      *
      * @ignore
      */
@@ -1356,23 +1428,6 @@ class API extends \Piwik\Plugin\API
         return $this->getModel()->getUniqueSiteTimezones();
     }
 
-    /**
-     * Insert the list of alias URLs for the website.
-     * The URLs must not exist already for this website!
-     */
-    private function insertSiteUrls($idSite, $urls)
-    {
-        if (count($urls) != 0) {
-            foreach ($urls as $url) {
-                try {
-                    $this->getModel()->insertSiteUrl($idSite, $url);
-                } catch(Exception $e) {
-                    // See bug #4149
-                }
-            }
-        }
-    }
-
     /**
      * Remove the final slash in the URLs if found
      *
@@ -1427,77 +1482,6 @@ class API extends \Piwik\Plugin\API
         }
     }
 
-    private function checkSiteSearch($siteSearch)
-    {
-        if ($siteSearch === null) {
-            return "1";
-        }
-        return $siteSearch == 1 ? "1" : "0";
-    }
-
-    private function checkSiteSearchParameters($searchKeywordParameters, $searchCategoryParameters)
-    {
-        $searchKeywordParameters = trim($searchKeywordParameters);
-        $searchCategoryParameters = trim($searchCategoryParameters);
-        if (empty($searchKeywordParameters)) {
-            $searchKeywordParameters = '';
-        }
-
-        if (empty($searchCategoryParameters)) {
-            $searchCategoryParameters = '';
-        }
-
-        return array($searchKeywordParameters, $searchCategoryParameters);
-    }
-
-    /**
-     * Check that the array of URLs are valid URLs
-     *
-     * @param array $urls
-     * @throws Exception if any of the urls is not valid
-     */
-    private function checkUrls($urls)
-    {
-        foreach ($urls as $url) {
-            if (!$this->isValidUrl($url)) {
-                throw new Exception(sprintf(Piwik::translate("SitesManager_ExceptionInvalidUrl"), $url));
-            }
-        }
-    }
-
-    /**
-     * Clean the parameter URLs:
-     * - if the parameter is a string make it an array
-     * - remove the trailing slashes if found
-     *
-     * @param string|array urls
-     * @return array the array of cleaned URLs
-     */
-    private function cleanParameterUrls($urls)
-    {
-        if (!is_array($urls)) {
-            $urls = array($urls);
-        }
-
-        $urls = array_filter($urls);
-        $urls = array_map('urldecode', $urls);
-
-        foreach ($urls as &$url) {
-            $url = $this->removeTrailingSlash($url);
-            $scheme = parse_url($url, PHP_URL_SCHEME);
-            if (empty($scheme)
-                && strpos($url, '://') === false
-            ) {
-                $url = 'http://' . $url;
-            }
-            $url = trim($url);
-            $url = Common::sanitizeInputValue($url);
-        }
-
-        $urls = array_unique($urls);
-        return $urls;
-    }
-
     public function renameGroup($oldGroupName, $newGroupName)
     {
         Piwik::checkUserHasSuperUserAccess();
@@ -1565,19 +1549,4 @@ class API extends \Piwik\Plugin\API
         return SettingsPiwik::getWebsitesCountToDisplay();
     }
 
-    /**
-     * Utility function that throws if a value is not valid for the 'keep_url_fragment'
-     * column of the piwik_site table.
-     *
-     * @param int $keepURLFragments
-     * @throws Exception
-     */
-    private static function checkKeepURLFragmentsValue($keepURLFragments)
-    {
-        // make sure value is between 0 & 2
-        if (!in_array($keepURLFragments, array(0, 1, 2))) {
-            throw new Exception("Error in SitesManager.updateSite: keepURLFragments must be between 0 & 2" .
-                " (actual value: $keepURLFragments).");
-        }
-    }
 }
