@@ -13,7 +13,7 @@ use Piwik\API\ResponseBuilder;
 use Piwik\Common;
 use Piwik\Exception\UnexpectedWebsiteFoundException;
 use Piwik\Piwik;
-use Piwik\Measurable\MeasurableSettings;
+use Piwik\Settings\Measurable\MeasurableSettings;
 use Piwik\SettingsPiwik;
 use Piwik\Site;
 use Piwik\Tracker\TrackerCodeGenerator;
@@ -34,26 +34,12 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
 
         return $this->renderTemplate('index');
     }
-
-    public function getMeasurableTypeSettings()
+    
+    public function globalSettings()
     {
-        $idSite = Common::getRequestVar('idSite', 0, 'int');
-        $idType = Common::getRequestVar('idType', '', 'string');
+        Piwik::checkUserHasSuperUserAccess();
 
-        if ($idSite >= 1) {
-            Piwik::checkUserHasAdminAccess($idSite);
-        } else if ($idSite === 0) {
-            Piwik::checkUserHasSomeAdminAccess();
-        } else {
-            throw new Exception('Invalid idSite parameter. IdSite has to be zero or higher');
-        }
-
-        $view = new View('@SitesManager/measurable_type_settings');
-
-        $propSettings   = new MeasurableSettings($idSite, $idType);
-        $view->settings = $propSettings->getSettingsForCurrentUser();
-
-        return $view->render();
+        return $this->renderTemplate('globalSettings');
     }
 
     public function getGlobalSettings()
@@ -155,6 +141,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
 
         return $this->renderTemplate('siteWithoutData', array(
             'siteName'     => $this->site->getName(),
+            'idSite' => $this->site->getId(),
             'trackingHelp' => $this->renderTemplate('_displayJavascriptCode', array(
                 'displaySiteName' => Common::unsanitizeInputValue($this->site->getName()),
                 'jsTag'           => $javascriptGenerator->generate($this->idSite, $piwikUrl),
