@@ -10,6 +10,7 @@ namespace Piwik\Plugins\UserCountry;
 
 use Exception;
 use Piwik\Archive;
+use Piwik\Container\StaticContainer;
 use Piwik\DataTable;
 use Piwik\Metrics;
 use Piwik\Piwik;
@@ -32,12 +33,12 @@ class API extends \Piwik\Plugin\API
         $dataTable = $this->getDataTable(Archiver::COUNTRY_RECORD_NAME, $idSite, $period, $date, $segment);
 
         // apply filter on the whole datatable in order the inline search to work (searches are done on "beautiful" label)
+        $dataTable->filter('AddSegmentValue');
         $dataTable->filter('ColumnCallbackAddMetadata', array('label', 'code'));
         $dataTable->filter('ColumnCallbackAddMetadata', array('label', 'logo', __NAMESPACE__ . '\getFlagFromCode'));
         $dataTable->filter('ColumnCallbackReplace', array('label', __NAMESPACE__ . '\countryTranslate'));
 
-        $dataTable->queueFilter('ColumnCallbackAddMetadata', array(array(), 'logoWidth', function () { return 16; }));
-        $dataTable->queueFilter('ColumnCallbackAddMetadata', array(array(), 'logoHeight', function () { return 11; }));
+        $dataTable->queueFilter('ColumnCallbackAddMetadata', array(array(), 'logoHeight', function () { return 16; }));
 
         return $dataTable;
     }
@@ -68,6 +69,9 @@ class API extends \Piwik\Plugin\API
     {
         $dataTable = $this->getDataTable(Archiver::REGION_RECORD_NAME, $idSite, $period, $date, $segment);
 
+        $segments = array('regionCode', 'countryCode');
+        $dataTable->filter('AddSegmentByLabel', array($segments, Archiver::LOCATION_SEPARATOR));
+
         $separator = Archiver::LOCATION_SEPARATOR;
         $unk = Visit::UNKNOWN_CODE;
 
@@ -110,6 +114,9 @@ class API extends \Piwik\Plugin\API
     {
         $dataTable = $this->getDataTable(Archiver::CITY_RECORD_NAME, $idSite, $period, $date, $segment);
 
+        $segments = array('city', 'regionCode', 'countryCode');
+        $dataTable->filter('AddSegmentByLabel', array($segments, Archiver::LOCATION_SEPARATOR));
+
         $separator = Archiver::LOCATION_SEPARATOR;
         $unk = Visit::UNKNOWN_CODE;
 
@@ -157,6 +164,24 @@ class API extends \Piwik\Plugin\API
         return $dataTable;
     }
 
+    /**
+     * Returns a simple mapping from country code to country name
+     *
+     * @return \string[]
+     */
+    public function getCountryCodeMapping()
+    {
+        $regionDataProvider = StaticContainer::get('Piwik\Intl\Data\Provider\RegionDataProvider');
+
+        $countryCodeList = $regionDataProvider->getCountryList();
+
+        array_walk($countryCodeList, function(&$item, $key) {
+            $item = Piwik::translate('Intl_Country_'.strtoupper($key));
+        });
+
+        return $countryCodeList;
+    }
+
     /**
      * Uses a location provider to find/guess the location of an IP address.
      *
@@ -173,12 +198,12 @@ class API extends \Piwik\Plugin\API
     {
         Piwik::checkUserHasSomeViewAccess();
 
-        if ($provider === false) {
+        if (empty($provider)) {
             $provider = LocationProvider::getCurrentProviderId();
         }
 
         $oProvider = LocationProvider::getProviderById($provider);
-        if ($oProvider === false) {
+        if (empty($oProvider)) {
             throw new Exception("Cannot find the '$provider' provider. It is either an invalid provider "
                 . "ID or the ID of a provider that is not working.");
         }
@@ -191,12 +216,31 @@ class API extends \Piwik\Plugin\API
         return $location;
     }
 
+    /**
+     * Set the location provider
+     *
+     * @param string $providerId  The ID of the provider to use  eg 'default', 'geoip_php', ...
+     * @throws Exception if ID is invalid
+     */
+    public function setLocationProvider($providerId)
+    {
+        Piwik::checkUserHasSuperUserAccess();
+
+        if (!UserCountry::isGeoLocationAdminEnabled()) {
+            throw new \Exception('Setting geo location has been disabled in config.');
+        }
+
+        $provider = LocationProvider::setCurrentProvider($providerId);
+        if ($provider === false) {
+            throw new Exception("Invalid provider ID: '$providerId'.");
+        }
+    }
+
     protected function getDataTable($name, $idSite, $period, $date, $segment)
     {
         Piwik::checkUserHasViewAccess($idSite);
         $archive = Archive::build($idSite, $period, $date, $segment);
         $dataTable = $archive->getDataTable($name);
-        $dataTable->filter('Sort', array(Metrics::INDEX_NB_VISITS));
         $dataTable->queueFilter('ReplaceColumnNames');
         return $dataTable;
     }
