@@ -26,18 +26,13 @@ use Piwik\View;
  */
 class Controller extends \Piwik\Plugin\ControllerAdmin
 {
-    public function index()
+    public function getDistinctCountries()
     {
-        $view = new View('@UserCountry/index');
+        $view = new View('@UserCountry/getDistinctCountries');
 
         $view->urlSparklineCountries = $this->getUrlSparkline('getLastDistinctCountriesGraph');
         $view->numberDistinctCountries = $this->getNumberOfDistinctCountries(true);
 
-        $view->dataTableCountry = $this->renderReport('getCountry');
-        $view->dataTableContinent = $this->renderReport('getContinent');
-        $view->dataTableRegion = $this->renderReport('getRegion');
-        $view->dataTableCity = $this->renderReport('getCity');
-
         return $view->render();
     }
 
@@ -53,6 +48,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
         $view->thisIP = IP::getIpFromHeader();
         $geoIPDatabasesInstalled = GeoIp::isDatabaseInstalled();
         $view->geoIPDatabasesInstalled = $geoIPDatabasesInstalled;
+        $view->updatePeriodOptions = $this->getPeriodUpdateOptions();
 
         // check if there is a working provider (that isn't the default one)
         $isThereWorkingProvider = false;
@@ -146,11 +142,21 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     private function getGeoIpUpdaterManageScreen()
     {
         $view = new View('@UserCountry/getGeoIpUpdaterManageScreen');
+
+        $view->updatePeriodOptions = $this->getPeriodUpdateOptions();
         $view->geoIPDatabasesInstalled = true;
         $this->setUpdaterManageVars($view);
         return $view->render();
     }
 
+    private function getPeriodUpdateOptions()
+    {
+        return array(
+            'month' => Piwik::translate('Intl_PeriodMonth'),
+            'week' => Piwik::translate('Intl_PeriodWeek')
+        );
+    }
+
     /**
      * Sets some variables needed by the _updaterManage.twig template.
      *
@@ -169,7 +175,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
 
         $lastRunTime = GeoIPAutoUpdater::getLastRunTime();
         if ($lastRunTime !== false) {
-            $view->lastTimeUpdaterRun = '<strong><em>' . $lastRunTime->toString() . '</em></strong>';
+            $view->lastTimeUpdaterRun = '<strong>' . $lastRunTime->toString() . '</strong>';
         }
 
         $view->nextRunTime = GeoIPAutoUpdater::getNextRunTime();
@@ -277,31 +283,6 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
         }
     }
 
-    /**
-     * Sets the current LocationProvider type.
-     *
-     * Input:
-     *   Requires the 'id' query parameter to be set to the desired LocationProvider's ID.
-     *
-     * Output:
-     *   Nothing.
-     */
-    public function setCurrentLocationProvider()
-    {
-        $this->dieIfGeolocationAdminIsDisabled();
-        Piwik::checkUserHasSuperUserAccess();
-        if ($_SERVER["REQUEST_METHOD"] == "POST") {
-            $this->checkTokenInUrl();
-
-            $providerId = Common::getRequestVar('id');
-            $provider = LocationProvider::setCurrentProvider($providerId);
-            if ($provider === false) {
-                throw new Exception("Invalid provider ID: '$providerId'.");
-            }
-            return 1;
-        }
-    }
-
     /**
      * Echo's a pretty formatted location using a specific LocationProvider.
      *
@@ -314,8 +295,8 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     public function getLocationUsingProvider()
     {
         $providerId = Common::getRequestVar('id');
-        $provider = $provider = LocationProvider::getProviderById($providerId);
-        if ($provider === false) {
+        $provider = LocationProvider::getProviderById($providerId);
+        if (empty($provider)) {
             throw new Exception("Invalid provider ID: '$providerId'.");
         }
 
