@@ -23,7 +23,6 @@ class UserLanguage extends \Piwik\Plugin
     {
         return array(
             'Live.getAllVisitorDetails'              => 'extendVisitorDetails',
-            'Request.getRenamedModuleAndAction' => 'renameUserSettingsModuleAndAction',
         );
     }
 
@@ -45,11 +44,4 @@ class UserLanguage extends \Piwik\Plugin
         $out .= '<h2 piwik-enriched-headline>' . Piwik::translate('UserLanguage_BrowserLanguage') . '</h2>';
         $out .= FrontController::getInstance()->fetchDispatch('UserLanguage', 'getLanguage');
     }
-
-    public function renameUserSettingsModuleAndAction(&$module, &$action)
-    {
-        if ($module == 'UserSettings' && ($action == 'getLanguage' || $action == 'getLanguageCode')) {
-            $module = 'UserLanguage';
-        }
-    }
 }
