@@ -18,7 +18,7 @@ use Piwik\Tracker\Visitor;
 class VisitsByDaysSinceLastVisit extends VisitDimension
 {
     protected $columnName = 'visitor_days_since_last';
-    protected $columnType = 'SMALLINT(5) UNSIGNED NOT NULL';
+    protected $columnType = 'SMALLINT(5) UNSIGNED NULL';
 
     protected function configureSegments()
     {
