@@ -8,12 +8,12 @@
  */
 namespace Piwik\Plugins\Widgetize;
 
-use Piwik\Menu\MenuUser;
+use Piwik\Menu\MenuAdmin;
 use Piwik\Piwik;
 
 class Menu extends \Piwik\Plugin\Menu
 {
-    public function configureUserMenu(MenuUser $menu)
+    public function configureAdminMenu(MenuAdmin $menu)
     {
         $tooltip   = Piwik::translate('Widgetize_TopLinkTooltip');
         $urlParams = $this->urlForAction('index', array('segment' => false));
